### This script downloads all available USGS conductivity data in
### the Bitter Creek watershed

# Clear working space
rm(list = ls())

# Load packages
library(tidyverse)
library(lubridate)
library(sf)
library(tmap)
library(readxl)
library(EnvStats)
library(quantreg)

# Load the data
dat_all <- read_csv("../_Datasets/Output/data_all.csv")

# Filter the conductivity data
dat_all2 <- dat_all %>%
  filter(Parameter %in% "SC") %>%
  filter(agency_cd %in% "USGS")

# Load the predicted median data
modeled <- read_excel("../_Datasets/Conductivity_Site_List_20210315.xlsx")

# Calculate the geomean
dat_summary <- dat_all2 %>%
  group_by(site_no, agency_cd, Latitude, Longitude, COMID) %>%
  summarize(Value = geoMean(Value),
            N = n()) %>%
  ungroup()

dat_summary2 <- dat_summary %>%
  left_join(modeled %>% dplyr::select(-Longitude, -Latitude), 
            by = c("site_no", "agency_cd", "COMID")) %>%
  mutate(Diff = Value - Median) %>%
  mutate(Label = ifelse(Diff > 0, "Yes",
                        ifelse(Diff < 0, "No", "Equal"))) %>%
  mutate(Abs = abs(Diff))

# How many stations with Value< 1004
sum(dat_summary2$Value < 1004)/nrow(dat_summary2) * 100
# [1] 33.56643

# How many stations with Value < 1004 for combined dataset?
dat_combined <- dat_all %>%
  filter(Parameter %in% "SC") 

dat_summary_combined <- dat_combined %>%
  group_by(site_no, agency_cd, Latitude, Longitude, COMID) %>%
  summarize(Value = geoMean(Value),
            N = n()) %>%
  ungroup()

dat_summary_combined2 <- dat_summary_combined %>%
  left_join(modeled %>% dplyr::select(-Longitude, -Latitude), 
            by = c("site_no", "agency_cd", "COMID")) %>%
  mutate(Diff = Value - Median) %>%
  mutate(Label = ifelse(Diff > 0, "Yes",
                        ifelse(Diff < 0, "No", "Equal"))) %>%
  mutate(Abs = abs(Diff))

sum(dat_summary_combined2$Value < 1004)/nrow(dat_summary_combined2) * 100
# [1] 25.63025

# Analyze the sample size and the Abs
dat_natural <- dat_summary2 %>%
  filter(Value < 1004)


p1 <- ggplot(dat_natural[dat_natural$N < 6, ], aes(x = N, y = Abs)) +
  scale_x_continuous(name = "Sample Size") +
  stat_summary(fun = geoMean, geom = "point", shape = 22, 
               size = 4, color = "black") +
  geom_point() +
  scale_y_continuous(name = "Absolute Difference (µS/cm)") +
  ggpubr::theme_pubr()

ggsave(filename = "../_Tables_Figures/Figures/USGS_predicted_category_natural.png", plot = p1,
       dpi = 1000)

# Identify the three sites that have sample size >= 6
dat_natural %>%
  filter(N >= 6) %>%
  pull(site_no)
  
# [1] "USGS-09216574"        "USGS-09216576"        "USGS-411038109042101"

### Look at the time-series plot of these three sies
P_N6_longterm <- dat_all %>%
  filter(site_no %in% c("USGS-09216574", "USGS-09216576", "USGS-411038109042101")) %>%
  filter(Parameter %in% "SC") %>%
  ggplot(aes(x = sample_dt, y = Value)) +
  geom_point() +
  # Add prediction
  geom_hline(data = dat_natural %>%
              filter(site_no %in% c("USGS-09216574", "USGS-09216576", "USGS-411038109042101")),
            aes(yintercept = Median), color = "blue") +
  facet_grid(site_no ~ .) +
  scale_y_log10(name = "SC (µS/cm)") +
  xlab("") +
  theme_bw() +
  theme(panel.grid = element_blank())

# ggsave(filename = "../_Tables_Figures/Figures/USGS_P_N6_longterm.png", plot = P_N6_longterm)

### Plot a scatter plot for the sites < 1004
line_dat <- tibble(
  x = 1:1000,
  y = 1:1000
)

p_scatter <- ggplot(dat_natural, aes(x = Value, y = Median)) +
  geom_point() +
  geom_line(data = line_dat, aes(x = x, y = y), color = "blue") +
  geom_vline(xintercept = 700, color = "red", linetype = "dashed") +
  scale_x_continuous(name = "Observed SC (µS/cm)", limits = c(50, 1000), trans = "log10",
                     breaks = c(100, 300, 500, 600, 700, 800, 900, 10000)) +
  scale_y_continuous(name = "Predicted background SC (µS/cm)", limits = c(50, 1000), trans = "log10",
                     breaks = c(100, 300, 500, 600, 700, 800, 900, 10000)) +
  ggpubr::theme_pubr()

ggsave(filename = "../_Tables_Figures/Figures/Cond_USGS_scatter_natural.png", plot = p_scatter, dpi = 1000)

sum(dat_natural$Value < 300)
# [1] 10

dat_natural %>%
  filter(Value < 300) %>%
  count(N)
# # A tibble: 2 x 2
#   N     n
#   <int> <int>
# 1     1     9
# 2     2     1

dat_natural %>%
  filter(N == 1) %>%
  nrow()
# [1] 30

dat_natural %>%
  filter(N == 1) %>%
  count(Label)
# 23/30
# [1] 0.7666667

max(dat_natural$Abs)
# [1] 540.8

dat_natural %>%
  filter(Value > 384)
# # A tibble: 37 x 11
# site_no              agency_cd Latitude Longitude   COMID Value     N Median    Diff Label    Abs
# <chr>                <chr>        <dbl>     <dbl>   <dbl> <dbl> <int>  <dbl>   <dbl> <chr>  <dbl>
#   1 USGS-09216574        USGS          41.2     -109. 3388953  806.    19   613   193.   Yes   193.  
# 2 USGS-09216576        USGS          41.2     -109. 3388945  838.    60   473   365.   Yes   365.  
# 3 USGS-09216580        USGS          41.3     -109. 3389869  435.     5   546. -111.   No    111.  
# 4 USGS-410341108593101 USGS          41.1     -109. 3390051  489.     2   504.  -15.0  No     15.0 
# 5 USGS-410414108595501 USGS          41.1     -109. 3390051  500      1   504.   -4.10 No      4.10
# 6 USGS-410423108593801 USGS          41.1     -109. 3390049  430      1   633. -203.   No    203.  
# 7 USGS-410510108591401 USGS          41.1     -109. 3390049  470      1   633. -163.   No    163.  
# 8 USGS-410520108583201 USGS          41.1     -109. 3390049  450.     2   633. -183.   No    183.  
# 9 USGS-410547108582301 USGS          41.1     -109. 3390049  510.     4   633. -123.   No    123.  
# 10 USGS-410730108571001 USGS          41.1     -109. 3390049  699.     4   633.   66.5  Yes    66.5 
# # ... with 27 more rows

### Remake the map

dat_summary_sf <- dat_summary2 %>%
  as.data.frame() %>%
  st_as_sf(coords = c("Longitude", "Latitude"), crs = 4326, remove = FALSE) 

huc_14040105 <- st_read("../_Datasets/GIS/BC_bound.shp")

# Load background conductivity data
bc <- read_excel("../_Datasets/BitterCreek_PredictedConductivityData.xls")

# # Download flowline
# flowline <- subset_nhdplus(bbox = st_bbox(huc_14040105), nhdplus_data = "download", status = FALSE, 
#                            return_data = TRUE, flowline_only = TRUE)

flowline <- readRDS("../_Datasets/bC_flowline.rds")

flowline_sp <- as(flowline, "Spatial")

flowline_sp@data <- flowline_sp@data %>%
  semi_join(bc, by = "COMID") %>%
  left_join(bc %>% select(OBJECTID, COMID, StreamName, AvgPredEC, F50Pct_PL), by = "COMID") %>%
  as.data.frame()

bbox <- tmaptools::bb(matrix(c(-109.6, 41.41, -108.8, 41.75),
                             2,
                             2))

# Define the rainbow palette
rainbow2 <- rev(rainbow(9))
rainbow2 <- c(rainbow2[3:7], "yellow", rainbow2[8], "tomato1", rainbow2[9])
rainbow2 <- rainbow2[1:6]
rainbow2[3] <- rainbow2[4]
rainbow2[4] <- "gold"
rainbow2[5] <- "goldenrod"
rainbow2[6] <- "brown"

map_no3_binary <- tm_shape(huc_14040105) +
  tm_borders() +
  tm_shape(flowline_sp) +
  tm_lines(col = "AvgPredEC",
           style = "fixed", breaks = c(0, 200, 400, 600, 800, 1000, 1200),
           palette = rainbow2,
           title.col = "Conductivity (μScm)") +
  tm_shape(dat_summary_sf %>% filter(Value < 1004)) +
  tm_symbols(col = "Label", size = 0.5,
             style = "fixed", border.col = "black",  
             palette = c("Yes" = "#f46d43", "No" = "#a6d96a", "Equal" = "black"),
             title.col = "Observed > Predicted") +
  tm_layout(frame = FALSE)

tmap_save(map_no3_binary, filename = "../_Tables_Figures/Figures/Cond_map_USGS_validation_binary_natural.png", dpi = 1000)