### This script downloads all available USGS conductivity data in
### the Bitter Creek watershed

# Clear working space
rm(list = ls())

# Load packages
library(tidyverse)
library(lubridate)
library(sf)
library(tmap)
library(readxl)
library(EnvStats)
library(quantreg)
library(scales)

# Load the data
dat_all <- read_csv("../_Datasets/Output/data_all.csv")

# Filter the conductivity data
dat_all2 <- dat_all %>%
  filter(Parameter %in% "SC") %>%
  filter(agency_cd %in% "USGS")

# Load the predicted median data
modeled <- read_excel("../_Datasets/Conductivity_Site_List_20210315.xlsx")

# Calculate the geomean
dat_summary <- dat_all2 %>%
  group_by(site_no, agency_cd, Latitude, Longitude, COMID) %>%
  summarize(Value = geoMean(Value),
            N = n()) %>%
  ungroup()

dat_summary2 <- dat_summary %>%
  left_join(modeled %>% dplyr::select(-Longitude, -Latitude), 
            by = c("site_no", "agency_cd", "COMID")) %>%
  mutate(Diff = Value - Median) %>%
  mutate(Label = ifelse(Diff > 0, "Yes",
                        ifelse(Diff < 0, "No", "Equal"))) %>%
  mutate(Abs = abs(Diff))

# In the 1088 samples, what is the percentage that < 1004?
mean(dat_all2$Value < 1004) * 100
# [1] 23.16176

# How many stations with Value< 1004
sum(dat_summary2$Value < 1004)/nrow(dat_summary2) * 100
# [1] 33.56643

# Filter the data with Value < 1004
dat_summary_s <- dat_summary2 %>%
  filter(Value < 1004)

# Calculate the MAE
hydroGOF::mae(dat_summary_s$Median, dat_summary_s$Value)
# [1] 210.5113

mean(dat_summary_s$Abs)
# [1] 210.5113

sd(dat_summary_s$Abs)
# [1] 150.4041

# Percentage of over-prediction
mean(dat_summary_s$Diff < 0)

# Filter the records with SC < 700
dat_summary_s2 <- dat_summary_s %>%
  filter(Value < 700)

dat_summary_s %>%
  filter(Value >= 700)

# Calculate the percentage of over prediction
sum(dat_summary_s2$Diff < 0)
# [1] 32
nrow(dat_summary_s2)
# [1] 35

### Find the maximum data for 09216545 and 09216565
dat_09216545 <- dat_all2 %>%
  filter(site_no %in% "USGS-09216545")

dat_09216565 <- dat_all2 %>%
  filter(site_no %in% "USGS-09216565")

# Find the maximum SC
max(dat_09216545$Value)
# [1] 4500

max(dat_09216565$Value)
# [1] 4000

# 90th percentile
quantile(dat_09216545$Value, probs = 0.9)
# 2320

quantile(dat_09216565$Value, probs = 0.9)
# 1400

### Calcualte the difference between the predicted backgound and 90th percentile
dat_all3 <- dat_all2 %>%
  filter(site_no %in% c("USGS-09216576",
                        "USGS-09216574",
                        "USGS-411038109042101",
                        "USGS-09216565")) %>%
  group_by(site_no, agency_cd, COMID) %>%
  summarize(Value_90th = quantile(Value, probs = 0.9)) %>%
  left_join(modeled %>% dplyr::select(-Longitude, -Latitude), 
            by = c("site_no", "agency_cd", "COMID")) %>%
  mutate(Diff = abs(Value_90th - Median))


# How many stations with Value < 1004 for combined dataset?
dat_combined <- dat_all %>%
  filter(Parameter %in% "SC") %>%
  #filter(Value >= 10)
  # Remove KC-6
  filter(!site_no %in% "KC-6")

dat_summary_combined <- dat_combined %>%
  group_by(site_no, agency_cd, Latitude, Longitude, COMID) %>%
  summarize(Value = geoMean(Value),
            N = n()) %>%
  ungroup()

dat_summary_combined2 <- dat_summary_combined %>%
  left_join(modeled %>% dplyr::select(-Longitude, -Latitude), 
            by = c("site_no", "agency_cd", "COMID")) %>%
  mutate(Diff = Value - Median) %>%
  mutate(Label = ifelse(Diff > 0, "Yes",
                        ifelse(Diff < 0, "No", "Equal"))) %>%
  mutate(Abs = abs(Diff))

# Find sites with any samples that is smaller than 645
dat_combined2 <- dat_combined %>%
  group_by(site_no, agency_cd, Latitude, Longitude, COMID) %>%
  summarize(Percent = mean(Value < 645) * 100,
            N = n())

dat_combined3 <- dat_combined2 %>%
  filter(N >= 6, Percent >= 10)


# Fit a linear regression model as x is predicted SC and y as 90th percentile
# in the station in dat_combined3


dat_summary_combined_f <- dat_combined %>%
  semi_join(dat_combined3, by = c("site_no", "agency_cd")) %>%
  group_by(site_no, agency_cd, Latitude, Longitude, COMID) %>%
  summarize(Value_90th = quantile(Value, probs = 0.9),
            N = n()) %>%
  ungroup() %>%
  left_join(dat_summary_combined2 %>%
              dplyr::select(-Value, -Diff, -Label, -Abs), 
            by = c("site_no", "agency_cd", "Latitude", "Longitude", "COMID", "N"))

ggplot(dat_summary_combined_f, aes(x = Median, y = Value_90th, size = N, color = agency_cd)) +
  geom_point() +
  scale_color_brewer(palette = "Set1") +
  scale_x_continuous(name = "Predicted SC") +
  scale_y_continuous(name = "90th SC") +
  theme_bw()

# Keep sites with Value_90th < 4000
dat_summary_combined_f2 <- dat_summary_combined_f %>%
  filter(Value_90th < 4000)


ggplot(dat_summary_combined_f2, aes(x = Median, y = Value_90th)) +
  geom_point(aes(size = N, color = agency_cd)) +
  scale_color_brewer(palette = "Set1") +
  scale_x_continuous(name = "Predicted SC") +
  scale_y_continuous(name = "90th SC") +
  theme_bw()


fit1 <- lm(Value_90th ~ Median, data = dat_summary_combined_f2)

dat_summary_combined_f3 <- dat_summary_combined_f2 %>%
  complete(Median = full_seq(Median, period = 0.1)) %>%
  mutate(Pred = predict(fit1, .)) %>%
  mutate(Pred_Interval_50 = predict(fit1, ., interval = "prediction", level = 0.5)) %>%
  mutate(Pred_Upper_50 = Pred_Interval_50[,"upr"],
         Pred_Lower_50 = Pred_Interval_50[,"lwr"]) %>%
  dplyr::select(-Pred_Interval_50) #%>%
  # mutate(Pred_Interval_90 = predict(fit1, ., interval = "prediction", level = 0.9)) %>%
  # mutate(Pred_Upper_90 = Pred_Interval_90[,"upr"],
  #        Pred_Lower_90 = Pred_Interval_90[,"lwr"]) %>%
  # dplyr::select(-Pred_Interval_90)

plot_90_lm <- ggplot(dat_summary_combined_f2, aes(x = Median, y = Value_90th)) +
  geom_point(aes(color = agency_cd, size = N)) +
  geom_line(data = dat_summary_combined_f3, aes(y = Pred), color = "blue") +
  geom_line(data = dat_summary_combined_f3, aes(y = Pred_Upper_50), color = "orange") +
  geom_line(data = dat_summary_combined_f3, aes(y = Pred_Lower_50), color = "orange") +
  # geom_label(data = data.frame(
  #   Equation = "y = -338.092 + 3.478 * x",
  #   x = 550, y = 2300
  # ), aes(x = x, y = y, label = Equation)) +
  # geom_label(data = data.frame(
  #   R2 = "R2: 0.27",
  #   x = 523, y = 2200
  # ), aes(x = x, y = y, label = R2)) +
  # geom_line(data = dat_summary_combined_f3, aes(y = Pred_Upper_90), color = "red") +
  # geom_line(data = dat_summary_combined_f3, aes(y = Pred_Lower_90), color = "red") +
  scale_color_brewer(name = "Agency", palette = "Set1") +
  scale_size_continuous(name = "Sample size") +
  scale_x_continuous(name = "Predicted background SC (µS/cm)", labels = comma) +
  scale_y_continuous(name = "The 90th percentile of the observed SC (µS/cm)", labels = comma) +
  theme_bw()

ggsave("../_Tables_Figures/Figures/The_90th_LM.png", plot = plot_90_lm, dpi = 300)

### Prepare the summary information for the seven sites

dat_90th <- dat_combined %>%
  semi_join(dat_summary_combined_f2, by = c("site_no", "agency_cd", "Latitude", "Longitude", "COMID")) %>%
  group_by(site_no, agency_cd, Latitude, Longitude, COMID) %>%
  summarize(Min = min(Value), 
            Per10 = quantile(Value, probs = 0.1),
            Per25 = quantile(Value, probs = 0.25),
            Per50 = quantile(Value, probs = 0.5),
            Per75 = quantile(Value, probs = 0.75),
            Per90 = quantile(Value, probs = 0.9),
            Max = max(Value),
            Mean = mean(Value),
            Geomean = geoMean(Value),
            SD = sd(Value),
            N = n()) %>%
  ungroup()

# Load Chris' stream site data
site_stream <- read_excel("../_Datasets/BC_Sites_with_RM.xlsx")

dat_90th_2 <- dat_90th %>%
  left_join(site_stream %>% select(site_no, Stream), by = "site_no") %>%
  left_join(modeled %>% dplyr::select(-Longitude, -Latitude), 
            by = c("site_no", "agency_cd", "COMID")) %>%
  relocate(Median, .before = "N") %>%
  rename(`Predicted BC` = Median) %>%
  relocate(Stream, .before = "COMID")
  
# write_csv(dat_90th_2, "../_Tables_Figures/Tables/Site_90th_info.csv")
