### This script cleans up and summarizes the data in Bitter Creek

# Clear working space
rm(list = ls())

# Load packages
library(tidyverse)
library(lubridate)
library(dataRetrieval)
library(sp)
library(sf)
library(rgdal)
library(readxl)
library(mapview)
library(nhdplusTools)
library(scales)
library(ggpubr)
library(tmap)
library(broom)
library(ggpubr)

# Load the data
dat_all <- read_csv("../_Datasets/Output/data_all.csv")

dat_all_median <- read_csv("../_Datasets/Output/data_all_median.csv")

dat_all2 <- dat_all %>%
  filter(Parameter %in% c("SC", "Cl", "SO4", "HCO3", "SO4_HCO3")) %>%
  select(-Outlier) %>%
  pivot_wider(names_from = "Parameter", values_from = "Value") %>%
  rename(Cl_mgl = Cl, HCO3_mgl = HCO3, SO4_mgl = SO4, SO4_HCO3_mgl = SO4_HCO3, Conductivity_uScm = SC)

### Step 1: Categorize the sites into three groups
dat_all3 <- dat_all2 %>%
  mutate(SO4_HCO3_mgl = SO4_mgl + HCO3_mgl) %>%
  mutate(Label = case_when(
    Cl_mgl >= SO4_HCO3_mgl  * 1                                      ~"Cl dominated",
    Cl_mgl < SO4_HCO3_mgl  * 1 & Cl_mgl > SO4_HCO3_mgl * 0.2         ~"Mixed",
    Cl_mgl <= SO4_HCO3_mgl * 0.2                                     ~"HCO3 + SO4 dominated",
    TRUE                                                             ~NA_character_
  )) %>%
  mutate(Label = factor(Label, levels = c(
    "HCO3 + SO4 dominated", "Mixed", "Cl dominated" 
  ))) %>%
  # Drop incomplete data
  drop_na(Label) 

table(dat_all3$Label)
# HCO3 + SO4 dominated                Mixed         Cl dominated 
#                  410                  439                   93 

### Create scatter plot (Plots in slide 12)
p1 <- ggplot(dat_all3, aes(x = SO4_HCO3_mgl, 
                           y = Cl_mgl,
                           fill = Label)) +
  geom_point(shape = 21, color = "black", size = 3) +
  scale_y_log10(name = "Cl (mg/L)",
                label = comma_format(accuracy = 0.01)) +
  scale_x_log10(name = "HCO3 + SO4 (mg/L)",
                label = comma_format(accuracy = 0.01)) +
  scale_fill_manual(values = c("HCO3 + SO4 dominated" = "#d9d9d9",
                               "Mixed" = "#8faade",
                               "Cl dominated" =  "#6a51a3")) +
  geom_abline(slope = 1, intercept = 1, color = "Red", size = 2) +
  geom_abline(slope = 1, intercept = 0.2, color = "Red", size = 2, linetype = "dashed") +
  theme_classic(base_size = 14) +
  theme(legend.position = "None")
print(p1)

ggsave(filename = "../_Tables_Figures/Figures//Cl_Scatter.png", plot = p1, dpi = 300, width = 7, height = 5)

### Create scatter plot by datasets
p2 <- p1 + 
  facet_grid(. ~ agency_cd) +
  theme_classic(base_size = 20) +
  theme(legend.position = "None")

ggsave(filename = "../_Tables_Figures/Figures/Cl_Scatter_agency.png", plot = p2, dpi = 300,
       width = 15, height = 5)

# Count sample size
dat_all3_agency_table <- dat_all3 %>% count(agency_cd, Label)
dat_all3_agency_table2 <- dat_all3 %>% count(Label)
dat_all3_agency_table3 <- bind_rows(dat_all3_agency_table2, dat_all3_agency_table) %>%
  replace_na(list(agency_cd = "Combined")) %>%
  pivot_wider(names_from = "agency_cd", values_from = "n") %>%
  arrange(desc(Label))

print(dat_all3_agency_table3)
#                  Label Combined SWCCD USGS WQD
# 1         Cl dominated       93    43    1  49
# 2                Mixed      439   114  157 168
# 3 HCO3 + SO4 dominated      410    91  264  55

write_csv(dat_all3_agency_table3, "../_Tables_Figures/Tables/Table4.csv")

### Step 2: Create scatter plot across different variable

dat_all4 <- dat_all3 %>%
  mutate(`Cl + HCO3 + SO4` = Cl_mgl + SO4_mgl + HCO3_mgl) %>%
  dplyr::select(site_no:sample_tm, Latitude, Longitude, `Specific Conductance` = Conductivity_uScm, Label, 
                Cl = Cl_mgl, SO4 = SO4_mgl, HCO3 = HCO3_mgl, `HCO3 + SO4` = SO4_HCO3_mgl, 
                `Cl + HCO3 + SO4`)
dat_all5 <- dat_all4 %>%
  pivot_longer(cols = -c(site_no, agency_cd, sample_dt, sample_tm, `Specific Conductance`, Label,
                         Latitude, Longitude), names_to = "Parameter", values_to = "Value") %>%
  mutate(Parameter = factor(Parameter, levels = c("Cl", "SO4", "HCO3", "HCO3 + SO4", "Cl + HCO3 + SO4"))) %>%
  mutate(Label = factor(Label, levels = c("HCO3 + SO4 dominated", "Mixed", "Cl dominated"))) %>%
  drop_na(`Specific Conductance`)

# Calculate the minimum SC in Chloride dominated
dat_all5 %>%
  filter(Label %in% "Cl dominated", Parameter %in% "Cl") %>%
  arrange(`Specific Conductance`) %>%
  pull(`Specific Conductance`) %>%
  head()
# [1]   18.982 1130.000 2000.000 3230.000 3650.000 4400.000

# Calculate the minimum Cl in Chloride dominated
dat_all5 %>%
  filter(Label %in% "Cl dominated", Parameter %in% "Cl") %>%
  arrange(Value) %>%
  pull(Value) %>%
  head()
# [1]  410.0000  650.3333  750.0000 1000.0000 1030.0000 1766.8333

p_corr <- ggplot(dat_all5, aes(x = `Specific Conductance`, y = Value)) +
  geom_point()+
  facet_grid(Parameter ~ Label) +
  geom_smooth(method = "lm", se = FALSE) +
  scale_x_log10(name = "Conductivity (μS/cm)", label = comma_format(1)) +
  scale_y_log10(name = "Concentration (mg/L)", label = comma_format(0.01)) +
  stat_cor(aes(label = ..rr.label..)) +
  theme_bw() +
  theme(panel.grid = element_blank())

p_corr2 <- ggplot(dat_all5, aes(x = `Specific Conductance`, y = Value)) +
  geom_point()+
  facet_grid(Parameter ~ Label) +
  geom_smooth(method = "lm", se = FALSE) +
  scale_x_log10(name = "Conductivity (μS/cm)", label = comma_format(1)) +
  scale_y_log10(name = "Concentration (mg/L)", label = comma_format(0.01)) +
  stat_cor(aes(label = ..rr.label..)) +
  stat_regline_equation(label.y = log10(100)) +
  theme_bw() +
  theme(panel.grid = element_blank())

# Remove outliers (Specific Conductance < 25)
dat_all5_r <- dat_all5 %>% filter(`Specific Conductance` > 25)

dat_all5_r %>%
  filter(Parameter %in% "Cl") %>%
  count(Label)
# # A tibble: 3 x 2
#   Label                    n
#   <fct>                <int>
# 1 HCO3 + SO4 dominated   406
# 2 Mixed                  420
# 3 Cl dominated            64

# Prepare a dataset with outliers
dat_all5_out <- dat_all5 %>% filter(`Specific Conductance` <= 25)

dat_all5_out %>%
  filter(Parameter %in% "Cl") %>%
  count(Label)

ggplot(dat_all5_r, aes(x = `Specific Conductance`, y = Value)) +
  geom_point()+
  facet_grid(Parameter ~ Label) +
  geom_smooth(method = "lm", se = FALSE) +
  scale_x_log10(name = "Conductivity (μS/cm)", label = comma_format(1)) +
  scale_y_log10(name = "Concentration (mg/L)", label = comma_format(0.01)) +
  stat_cor(aes(label = ..rr.label..)) +
  stat_regline_equation(label.y = log10(100)) +
  theme_bw() +
  theme(panel.grid = element_blank())

### Fit linear regression models for each combination
dat_all5_lm <- dat_all5_r %>%
  rename(SC = `Specific Conductance`) %>%
  mutate(SC = log10(SC), Value = log10(Value)) %>%
  group_by(Label, Parameter) %>%
  nest() %>%
  mutate(Fit = map(data, function(x){
    fit <- lm(Value ~ SC, data = x)
    return(fit)
  })) %>%
  mutate(Metric = map(Fit, glance),
         Coef = map(Fit, tidy))

# Prepare a summary table with R2 and coefficients
dat_all5_lm2 <- dat_all5_lm %>%
  mutate(R2 = map_dbl(Metric, function(x){
    x2 <- x %>% pull("r.squared")
    return(x2)
  })) %>%
  mutate(Coef2 = map(Coef, function(x){
    x2 <- x %>%
      dplyr::select(term, estimate) %>%
      mutate(term = recode(term, "(Intercept)" = "Intercept", "Specific Conductance" = "SC")) %>%
      spread(term, estimate)
  })) %>%
  mutate(Sample_Size = map_int(Fit, function(x) length(x$residuals))) %>%
  dplyr::select(Label, Parameter, R2, Coef2, Sample_Size) %>%
  unnest(cols = "Coef2")

# For HCO3+SO4 and Cl, fit a regression model that only uses SC between 500 to 1000
HCO3_SO4_lm <- dat_all5_lm %>% 
  filter(Parameter %in% "Cl", Label %in% "HCO3 + SO4 dominated") %>%
  dplyr::select(Label, Parameter, data) %>%
  mutate(data = map(data, function(x){
    x2 <- x %>% 
      filter(SC >= log10(500), SC <= log10(1000)) 
    return(x2)
  })) %>%
  mutate(Fit = map(data, function(x){
    fit <- lm(Value ~ SC, data = x)
    return(fit)
  }))

# Print the R2
summary(HCO3_SO4_lm$Fit[[1]])$r.squared
# [1] 0.1328338

# The model based on SC between 500 to 1000 has a low R2, so considering use the model with full range

# Fit the linear regression to full Cl data
dat_all5_r_Cl <- dat_all5_r %>%
  filter(Parameter %in% "Cl") 

dat_all5_r_Cl2 <- dat_all5_r_Cl %>%
  rename(SC = `Specific Conductance`) %>%
  mutate(SC = log10(SC), Value = log10(Value))

Combine_Cl_lm <- lm(Value ~ SC, data = dat_all5_r_Cl2)

print(Combine_Cl_lm)
# Call:
#   lm(formula = Value ~ SC, data = dat_all5_r_Cl2)
# 
# Coefficients:
#   (Intercept)           SC  
#        -3.868        1.759

# Print the sample size
length(Combine_Cl_lm$residuals)
# 890

# Print the Chloride regression in HCO3 + SO4 dominated
Low_Cl_lm <- dat_all5_lm %>%
  filter(Label %in% "HCO3 + SO4 dominated", Parameter %in% "Cl") %>%
  pluck("Fit", 1) 

print(Low_Cl_lm)
# Call:
#   lm(formula = Value ~ SC, data = x)
# 
# Coefficients:
#   (Intercept)           SC  
#        -3.477        1.588 

# Print the Chloride regression in Mixed
Mixed_Cl_lm <- dat_all5_lm %>%
  filter(Label %in% "Mixed", Parameter %in% "Cl") %>%
  pluck("Fit", 1) 

print(Mixed_Cl_lm)
# Call:
#   lm(formula = Value ~ SC, data = x)
# 
# Coefficients:
#   (Intercept)           SC  
#        -1.598        1.205

# Print the Chloride regression in Mixed
High_Cl_lm <- dat_all5_lm %>%
  filter(Label %in% "Cl dominated", Parameter %in% "Cl") %>%
  pluck("Fit", 1) 

print(High_Cl_lm)
# Call:
#   lm(formula = Value ~ SC, data = x)
# 
# Coefficients:
#   (Intercept)           SC  
#        0.4936       0.7557

# Using these four models, predict the Chloride concentration when SC = 809.83

# Combined
10^predict(Combine_Cl_lm, newdata = tibble(SC = log10(809.83)))
#        1 
# 17.70238

# HCO3 + SO4 dominated
10^predict(Low_Cl_lm, newdata = tibble(SC = log10(809.83)))
#        1 
# 13.90363

# Mixed
10^predict(Mixed_Cl_lm, newdata = tibble(SC = log10(809.83)))
#        1 
# 80.95215

# Cl dominated
10^predict(High_Cl_lm, newdata = tibble(SC = log10(809.83)))
#        1 
# 491.5639 

# Plot 
p_full_cl <- ggplot(dat_all5_r_Cl, aes(x = `Specific Conductance`, y = Value)) +
  geom_point(aes(fill = Label), shape = 21, color = "black", size = 2) +
  scale_x_log10(name = "Conductivity (μS/cm)", label = comma_format(1)) +
  scale_y_log10(name = "Chloride Concentration (mg/L)", label = comma_format(0.01)) +
  # scale_color_brewer(type = "qual", palette = "Set2") +
  scale_fill_manual(values = c("HCO3 + SO4 dominated" = "#d9d9d9",
                               "Mixed" = "#8faade",
                               "Cl dominated" =  "#6a51a3")) +
  geom_smooth(method = "lm", se = FALSE) +
  stat_cor(aes(label = ..rr.label..)) +
  stat_regline_equation(label.y = log10(1000)) +
  geom_point(data = dat_all5_out %>% filter(Parameter %in% "Cl"), 
             aes(x = `Specific Conductance`, y = Value), color = "red", size = 2) +
  theme_bw() +
  theme(panel.grid = element_blank())

# ggsave("../_Tables_Figures/Figures/parameter_corplot_full_cl.png", plot = p_full_cl, height = 5, width = 8, dpi = 300)

### Plot the data, keep the outliers in the plot but generate regression line without outliers 
p_corr_r <- ggplot(dat_all5_r, aes(x = `Specific Conductance`, y = Value)) +
  geom_point()+
  facet_grid(Parameter ~ Label) +
  geom_smooth(method = "lm", se = FALSE) +
  scale_x_log10(name = "Conductivity (μS/cm)", label = comma_format(1)) +
  scale_y_log10(name = "Concentration (mg/L)", label = comma_format(0.01)) +
  stat_cor(aes(label = ..rr.label..)) +
  stat_regline_equation(label.y = log10(100)) +
  theme_bw() +
  theme(panel.grid = element_blank())

# ggsave("../_Tables_Figures/Figures/parameter_corplot2.png", plot = p_corr_r, height = 8, width = 7, dpi = 300)

### Plot the data, keep the outliers in the plot but generate regression line with outliers (Plot in slide 14)
p_corr_out <- ggplot(dat_all5_r, aes(x = `Specific Conductance`, y = Value)) +
  geom_point()+
  facet_grid(Parameter ~ Label) +
  geom_smooth(method = "lm", se = FALSE) +
  scale_x_log10(name = "Conductivity (μS/cm)", label = comma_format(1)) +
  scale_y_log10(name = "Concentration (mg/L)", label = comma_format(0.01)) +
  stat_cor(aes(label = ..rr.label..),
           label.x = log10(1.2), label.y = log10(700)) +
  stat_regline_equation(label.y = log10(95)) +
  geom_point(data = dat_all5_out, aes(x = `Specific Conductance`, y = Value), color = "red") +
  theme_bw() +
  theme(panel.grid = element_blank(),
        strip.background = element_rect(fill = "white"),
        strip.text = element_text(size = 14))

ggsave("../_Tables_Figures/Figures/parameter_corplot.png", plot = p_corr_out, height = 10, width = 10, dpi = 1000)

# A version with panel plot but only focus on Cl
p_corr_out_Cl_only <- ggplot(dat_all5_r %>% filter(Parameter %in% "Cl"),
                             aes(x = `Specific Conductance`, y = Value)) +
  geom_point()+
  facet_grid(Parameter ~ Label) +
  geom_smooth(method = "lm", se = FALSE) +
  # 793 is a target threshold to visualize
  geom_vline(xintercept = 793, linetype = "dashed", color = "darkgreen", size = 1) +
  scale_x_log10(name = "Conductivity (μS/cm)", label = comma_format(1)) +
  scale_y_log10(name = "Concentration (mg/L)", label = comma_format(0.01)) +
  geom_point(data = dat_all5_out %>% filter(Parameter %in% "Cl"),
             aes(x = `Specific Conductance`, y = Value), color = "red") +
  theme_bw(base_size = 18) +
  theme(panel.grid = element_blank())

# ggsave(filename = "../_Tables_Figures/Figures/parameter_corplot3_Cl_focus.png", plot = p_corr_out_Cl_only,
#        width = 11, height = 4)

# A version with panel plot but only focus on Cl, and with combined plot
Cl_dat <- dat_all5_r %>% filter(Parameter %in% "Cl")

Cl_dat_combined <- Cl_dat %>% mutate(Label = "Combined")

Cl_dat2 <- Cl_dat %>% 
  bind_rows(Cl_dat_combined) %>%
  mutate(Label = factor(Label,
                        levels = c("Combined", "HCO3 + SO4 dominated",
                                   "Mixed", "Cl dominated")))

Cl_dat_out <- dat_all5_out %>% filter(Parameter %in% "Cl")

Cl_dat_out_combined <- Cl_dat_out %>% mutate(Label = "Combined")

Cl_dat_out2 <- Cl_dat_out %>% bind_rows(Cl_dat_out_combined ) %>%
  mutate(Label = factor(Label,
                        levels = c("Combined", "HCO3 + SO4 dominated",
                                   "Mixed", "Cl dominated")))

p_corr_out_Cl_only_combined <- ggplot(Cl_dat2, aes(x = `Specific Conductance`, y = Value)) +
  geom_point()+
  facet_grid(Parameter ~ Label) +
  geom_smooth(method = "lm", se = FALSE) +
  scale_x_log10(name = "Conductivity (μS/cm)", label = comma_format(1)) +
  scale_y_log10(name = "Concentration (mg/L)", label = comma_format(0.01)) +
  stat_cor(aes(label = ..r.label..)) +
  stat_regline_equation(label.y = log10(100)) +
  geom_point(data = Cl_dat_out2,
             aes(x = `Specific Conductance`, y = Value), color = "red") +
  theme_bw(base_size = 18) +
  theme(panel.grid = element_blank(),
        strip.background = element_rect(fill = "white"))

ggsave(filename = "../_Tables_Figures/Figures/parameter_corplot3_Cl_focus_combined.png", 
       plot = p_corr_out_Cl_only_combined,
       width = 12, height = 4)

### Step 3: Create site map

# ### Load the watershed boundary
# # Access to the geodatabase and list all features
# fgdb <- "C:/Users/YUCHEN.WANG/Documents/HTF/HTF_Flow/wbd_dir/WBD_National_GDB.gdb"
# 
# # List all feature classes in a file geodatabase
# fc_list <- ogrListLayers(fgdb)
# print(fc_list)
# 
# # Read WBDHU8
# wbd8 <- st_read(fgdb, layer = "WBDHU8")
# 
# # Find the HUC8:14040105
# huc_14040105 <- wbd8 %>% filter(huc8 %in% "14040105")
# 
# # Save a shape file
# st_write(huc_14040105, "BC_bound.shp", overwrite = TRUE)

# Load the shapefile
huc_14040105 <- st_read("../_Datasets/GIS/BC_bound.shp")

# Take a look at the boundary of the watershed
mapview(huc_14040105)

# rm(wbd8)

### Donwload flowline

# Load background conductivity data
bc <- read_excel("../_Datasets/BitterCreek_PredictedConductivityData.xls")

# # Download flowline
# flowline <- subset_nhdplus(bbox = st_bbox(huc_14040105), nhdplus_data = "download", status = FALSE, 
#                            return_data = TRUE, flowline_only = TRUE)

flowline <- readRDS("../_Datasets/GIS/BC_flowline.rds")

flowline_sp <- as(flowline, "Spatial")

flowline_sp@data <- flowline_sp@data %>%
  semi_join(bc, by = "COMID") %>%
  left_join(bc %>% dplyr::select(OBJECTID, COMID, StreamName, AvgPredEC, F50Pct_PL), by = "COMID") %>%
  as.data.frame()

# Filter the flowline based on bc
flowline_bc <- flowline %>%
  semi_join(bc, by = "COMID") %>%
  left_join(bc %>% dplyr::select(OBJECTID, COMID, StreamName, AvgPredEC, F50Pct_PL), by = "COMID")

flowline_bc2 <- flowline_bc %>%
  dplyr::select(OBJECTID, COMID, StreamName, AvgPredEC, F50Pct_PL, FTYPE, Shape_Length)

# Convert dat_all3 to sf object
dat_all3_median_sf <- dat_all3 %>%
  group_by(site_no, agency_cd, Latitude, Longitude, COMID) %>%
  summarize(across(Conductivity_uScm:SO4_HCO3_mgl, .fns = median)) %>%
  ungroup() %>%
  mutate(Label = case_when(
    Cl_mgl >= SO4_HCO3_mgl  * 1                                      ~"Cl dominated",
    Cl_mgl < SO4_HCO3_mgl  * 1 & Cl_mgl > SO4_HCO3_mgl * 0.2         ~"Mixed",
    Cl_mgl <= SO4_HCO3_mgl * 0.2                                     ~"HCO3 + SO4 dominated",
    TRUE                                                             ~NA_character_
  )) %>%
  mutate(Label = factor(Label, levels = c(
    "HCO3 + SO4 dominated", "Mixed", "Cl dominated" 
  ))) %>%
  st_as_sf(coords = c("Longitude", "Latitude"), crs = 4326, remove = FALSE)

# Plot the background conductivity
map1 <- tm_shape(huc_14040105) +
  tm_borders() +
  tm_shape(flowline_bc2) +
  tm_lines(col = "AvgPredEC", title.col = "Predicted Conductivity (μScm)", lwd = 2,
           palette = RColorBrewer::brewer.pal(n = 7, name = "YlOrRd")[2:7]) +
  tm_shape(dat_all3_median_sf) +
  tm_symbols(col = "Label", size = 0.5, shape = "agency_cd",
             palette = c("HCO3 + SO4 dominated" = "#d9d9d9", "Mixed" = "#8faade", "Cl dominated" = "#6a51a3"),
             title.col = "Ion Group", title.shape = "Agency") +
  tm_scale_bar() +
  tm_compass(position = c("right", "top"), size = 4) +
  tm_layout(frame = FALSE, legend.outside = TRUE, legend.outside.size = 0.2)
  
### Conductivity map

# Use all available conductivity data
dat_median_cond_sf <- dat_all_median %>%
  filter(Parameter %in% "SC") %>%
  as.data.frame() %>%
  st_as_sf(coords = c("Longitude", "Latitude"), crs = 4326, remove = FALSE)

flowline_bc3 <- flowline %>%
  st_geometry()

rainbow1 <- rev(rainbow(9))
rainbow1 <- c(rainbow1[3:7], "yellow", rainbow1[8], "tomato1", rainbow1[9])

map3 <- tm_shape(huc_14040105) +
  tm_borders() +
  tm_shape(flowline_bc3) +
  tm_lines(col = "blue") +
  tm_shape(dat_median_cond_sf) +
  tm_symbols(col = "Value", size = 0.5, shape = "agency_cd",
             style = "fixed", breaks = c(0, 200, 400, 600, 800, 1000, 2000, 5000, 10000, 100000),
             palette = rainbow1,
             title.col = "Conductivity (μScm)", title.shape = "Agency") +
  tm_scale_bar() +
  tm_compass(position = c("right", "top"), size = 4) +
  tm_layout(legend.show = FALSE, frame = FALSE)

# tmap_save(map3, filename = "../_Tables_Figures/Figures/map_conductivity.png", dpi = 300)

map3_legend <- tm_shape(huc_14040105) +
  tm_borders() +
  tm_shape(flowline_bc3) +
  tm_lines(col = "black") +
  tm_shape(dat_median_cond_sf) +
  tm_symbols(col = "Value", size = 0.5, shape = "agency_cd",
             style = "fixed", breaks = c(0, 200, 400, 600, 800, 1000, 2000, 5000, 10000, 100000),
             palette = rainbow1,
             title.col = "Conductivity (μScm)", title.shape = "Agency") +
  tm_layout(legend.only = TRUE, frame = FALSE)

# tmap_save(map3_legend, filename = "../_Tables_Figures/Figures/map_conductivity_legend.png", dpi = 1000)

rainbow2 <- rev(rainbow(9))
rainbow2 <- c(rainbow2[3:7], "yellow", rainbow2[8], "tomato1", rainbow2[9])
rainbow2 <- rainbow2[1:6]
rainbow2[3] <- rainbow2[4]
rainbow2[4] <- "gold"
rainbow2[5] <- "goldenrod"
rainbow2[6] <- "brown"

map3_com <- tm_shape(huc_14040105) +
  tm_borders() +
  tm_shape(flowline_sp) +
  tm_lines(col = "AvgPredEC",
           style = "fixed", breaks = c(0, 200, 400, 600, 800, 1000, 1200),
           palette = rainbow2,
           title.col = "Conductivity (μScm)") +
  tm_shape(dat_median_cond_sf) +
  tm_symbols(col = "Value", size = 0.5, shape = "agency_cd",
             style = "fixed", breaks = c(0, 200, 400, 600, 800, 1000, 2000, 5000, 10000, 100000),
             palette = rainbow1,
             title.col = "Conductivity (μScm)", title.shape = "Agency") +
  tm_scale_bar(text.size = 1) +
  tm_compass(position = c("right", "top"), size = 4) +
  tm_layout(frame = FALSE, legend.show = FALSE)

tmap_save(map3_com, filename = "../_Tables_Figures/Figures/map_conductivity_combine.png", dpi = 1000)

map3_com_legend <- tm_shape(huc_14040105) +
  tm_borders() +
  tm_shape(flowline_sp) +
  tm_lines(col = "AvgPredEC",
           style = "fixed", breaks = c(0, 200, 400, 600, 800, 1000, 1200),
           palette = rainbow2,
           title.col = "Conductivity (μScm)") +
  tm_shape(dat_median_cond_sf) +
  tm_symbols(col = "Value", size = 0.5, shape = "agency_cd",
             style = "fixed", breaks = c(0, 200, 400, 600, 800, 1000, 2000, 5000, 10000, 100000),
             palette = rainbow1,
             title.col = "Conductivity (μScm)", title.shape = "Agency") +
  tm_scale_bar(text.size = 1) +
  tm_compass(position = c("right", "top"), size = 4) +
  tm_layout(frame = FALSE, legend.only = TRUE)

tmap_save(map3_com_legend, filename = "../_Tables_Figures/Figures/map_conductivity_combine_legend.png", dpi = 1000)

# # Zoom in version of map3_com
# 
# # Create a bbox
# bbox_map3 <- st_bbox(c("xmin" = -109.4, "ymin" = 41.53, "xmax" = -109.1, "ymax" = 41.65))
# 
# map3_com_zoom <- tm_shape(huc_14040105, bbox = bbox_map3) +
#   tm_borders() +
#   tm_shape(flowline_sp, bbox = bbox_map3) +
#   tm_lines(col = "AvgPredEC",
#            style = "fixed", breaks = c(0, 200, 400, 600, 800, 1000, 1200),
#            palette = rainbow2,
#            title.col = "Conductivity (μScm)") +
#   tm_shape(dat_median_cond_sf, bbox = bbox_map3) +
#   tm_symbols(col = "Value", size = 0.5, shape = "agency_cd",
#              style = "fixed", breaks = c(0, 200, 400, 600, 800, 1000, 2000, 5000, 10000, 100000),
#              palette = rainbow1,
#              title.col = "Conductivity (μScm)", title.shape = "Agency") +
#   tm_scale_bar(text.size = 1) +
#   tm_compass(position = c("right", "top"), size = 4) +
#   tm_layout(frame = TRUE, legend.show = FALSE)
# 
# tmap_save(map3_com_zoom, filename = "Output/map_conductivity_combine_zoom.png", dpi = 1000)
# 
# # Plot the legend and compared with map3_com_legend as a check
# map3_com_zoom_legend <- tm_shape(huc_14040105, bbox = bbox_map3) +
#   tm_borders() +
#   tm_shape(flowline_sp, bbox = bbox_map3) +
#   tm_lines(col = "AvgPredEC",
#            style = "fixed", breaks = c(0, 200, 400, 600, 800, 1000, 1200),
#            palette = rainbow2,
#            title.col = "Conductivity (μScm)") +
#   tm_shape(dat_median_cond_sf, bbox = bbox_map3) +
#   tm_symbols(col = "Value", size = 0.5, shape = "agency_cd",
#              style = "fixed", breaks = c(0, 200, 400, 600, 800, 1000, 2000, 5000, 10000, 100000),
#              palette = rainbow1,
#              title.col = "Conductivity (μScm)", title.shape = "Agency") +
#   tm_scale_bar(text.size = 1) +
#   tm_compass(position = c("right", "top"), size = 4) +
#   tm_layout(frame = FALSE, legend.only = TRUE)




# remake of map1 using the same color palette as in map3_com
map1_com <- tm_shape(huc_14040105) +
  tm_borders() +
  tm_shape(flowline_sp) +
  tm_lines(col = "AvgPredEC",
           style = "fixed", breaks = c(0, 200, 400, 600, 800, 1000, 1200),
           palette = rainbow2,
           title.col = "Conductivity (μScm)") +
  tm_shape(dat_all3_median_sf) +
  tm_symbols(col = "Label", size = 0.5, shape = "agency_cd",
             palette = c("HCO3 + SO4 dominated" = "#d9d9d9", "Mixed" = "#8faade", "Cl dominated" = "#6a51a3"),
             title.col = "Ion Group", title.shape = "Agency") +
  tm_scale_bar(text.size = 1) +
  tm_compass(position = c("right", "top"), size = 4) +
  tm_layout(frame = FALSE, legend.show = FALSE)

map1_legend <- tm_shape(huc_14040105) +
  tm_borders() +
  tm_shape(flowline_sp) +
  tm_lines(col = "AvgPredEC",
           style = "fixed", breaks = c(0, 200, 400, 600, 800, 1000, 1200),
           palette = rainbow2,
           title.col = "Conductivity (μScm)") +
  tm_shape(dat_all3_median_sf) +
  tm_symbols(col = "Label", size = 0.5, shape = "agency_cd",
             palette = c("HCO3 + SO4 dominated" = "#d9d9d9", "Mixed" = "#8faade", "Cl dominated" = "#6a51a3"),
             title.col = "Ion Group", title.shape = "Agency") +
  tm_layout(frame = FALSE, legend.only = TRUE)

tmap_save(map1_com, filename = "../_Tables_Figures/Figures/map_all.png", dpi = 1000)
tmap_save(map1_legend, filename = "../_Tables_Figures/Figures/map_all_legend.png", dpi = 1000)

### Conductivity histogram

p3_1 <- ggplot(dat_all_median %>%
                 filter(Parameter %in% "SC"), aes(x = Value)) +
  geom_histogram(fill = "white", color = "black") +
  xlab("Conductivity (μScm)") +
  geom_vline(xintercept = 1500, size = 2, linetype = "dashed") +
  scale_x_log10(label = comma) +
  theme_pubr()

dat_all_median_SC <- dat_all_median %>%
  filter(Parameter %in% "SC")

dat_all_median_SC_r <- dat_all_median_SC %>%
  mutate(agency_cd = "Combined")

dat_all_median_SC2 <- bind_rows(dat_all_median_SC, dat_all_median_SC_r) %>%
  mutate(agency_cd = factor(agency_cd, 
                            levels = c("Combined", "SWCCD", "USGS",
                                       "AML", "LQD", "WQD")))

p3_2 <- ggplot(dat_all_median_SC2, aes(x = Value)) +
  geom_histogram(fill = "white", color = "black") +
  xlab("Conductivity (μScm)") +
  facet_wrap( ~ agency_cd, ncol = 3, scales = "free_y") +
  geom_vline(xintercept = 1500, size = 2, linetype = "dashed") +
  scale_x_log10(label = comma) +
  theme_pubr(base_size = 20) +
  theme(strip.background = element_rect(fill = "white"),
        strip.text = element_text(size = 20))

ggsave(filename = "../_Tables_Figures/Figures/cond_hist_agency_all.png", 
       plot = p3_2, dpi = 300, height = 14, width = 20)

# Show the percentage < 1500 of each category
dat_all_median_SC2 %>%
  group_by(agency_cd) %>%
  summarize(Percentage = sum(Value < 1500)/n() * 100) %>%
  as.data.frame()
#   agency_cd Percentage
# 1  Combined  34.873950
# 2     SWCCD  22.033898
# 3      USGS  44.755245
# 4       AML   0.000000
# 5       LQD  50.000000
# 6       WQD   7.692308

# Conductivity histogram with all available data
dat_all_SC <- dat_all %>%
  filter(Parameter %in% "SC")

dat_all_SC_r <- dat_all_SC %>%
  mutate(agency_cd = "Combined")

dat_all_SC2 <- bind_rows(dat_all_SC, dat_all_SC_r) %>%
  mutate(agency_cd = factor(agency_cd, 
                            levels = c("Combined", "SWCCD", "USGS",
                                       "AML", "LQD", "WQD")))

p3_3 <- ggplot(dat_all_SC2, aes(x = Value)) +
  geom_histogram(fill = "white", color = "black") +
  xlab("Conductivity (μScm)") +
  facet_wrap( ~ agency_cd, ncol = 3, scales = "free_y") +
  geom_vline(xintercept = 1500, size = 2, linetype = "dashed") +
  scale_x_log10(label = comma) +
  theme_pubr(base_size = 20) +
  theme(strip.background = element_rect(fill = "white"),
        strip.text = element_text(size = 20))

ggsave(filename = "../_Tables_Figures/Figures/cond_hist_agency_multiple_all.png", 
       plot = p3_3, dpi = 300, height = 14, width = 20)

# Show the percentage < 1500 of each category
dat_all_SC2 %>%
  group_by(agency_cd) %>%
  summarize(Percentage = sum(Value < 1500)/n() * 100) %>%
  as.data.frame()
#   agency_cd Percentage
# 1  Combined  27.520916
# 2     SWCCD  16.148148
# 3      USGS  40.716912
# 4       AML  10.465116
# 5       LQD  62.500000
# 6       WQD   3.787879

### Chloride map

dat_median_Cl_sf <- dat_all_median %>%
  filter(Parameter %in% "Cl") %>%
  as.data.frame() %>%
  st_as_sf(coords = c("Longitude", "Latitude"), crs = 4326, remove = FALSE)

map5 <- tm_shape(huc_14040105) +
  tm_borders() +
  tm_shape(flowline_bc3) +
  tm_lines(col = "black") +
  tm_shape(dat_median_Cl_sf) +
  tm_symbols(col = "Value", size = 0.5, shape = "agency_cd",
             palette = rainbow1,
             style = "fixed", breaks = c(0, 25, 50, 100, 200, 500, 1000, 2000, 10000, 55000),
             title.col = "Chloride (mg/L)", title.shape = "Agency") +
  tm_scale_bar() +
  tm_compass(position = c("right", "top"), size = 4) +
  tm_layout(legend.show = FALSE, frame = FALSE)

# tmap_save(map5, filename = "../_Tables_Figures/Figures//map_cl.png", dpi = 300)

map6 <- tm_shape(huc_14040105) +
  tm_borders() +
  tm_shape(flowline_bc3) +
  tm_lines(col = "black") +
  tm_shape(dat_median_Cl_sf) +
  tm_symbols(col = "Value", size = 0.5, shape = "agency_cd",
             style = "fixed", breaks = c(0, 25, 50, 100, 200, 500, 1000, 2000, 10000, 55000),
             palette = rainbow1,
             title.col = "Chloride (mg/L)", title.shape = "Agency") +
  tm_scale_bar() +
  tm_compass(position = c("right", "top"), size = 4) +
  tm_layout(legend.only = TRUE, frame = FALSE)

# tmap_save(map6, filename = "../_Tables_Figures/Figures//map_cl_legend.png", dpi = 1000)

map5_com <- tm_shape(huc_14040105) +
  tm_borders() +
  tm_shape(flowline_sp) +
  tm_lines(col = "AvgPredEC",
           style = "fixed", breaks = c(0, 200, 400, 600, 800, 1000, 1200),
           palette = rainbow2,
           title.col = "Conductivity (μScm)") +
  tm_shape(dat_median_Cl_sf) +
  tm_symbols(col = "Value", size = 0.5, shape = "agency_cd",
             palette = rainbow1,
             style = "fixed", breaks = c(0, 25, 50, 100, 200, 500, 1000, 2000, 10000, 55000),
             title.col = "Chloride (mg/L)", title.shape = "Agency") +
  tm_scale_bar(text.size = 1) +
  tm_compass(position = c("right", "top"), size = 4) +
  tm_layout(legend.show = FALSE, frame = FALSE)

tmap_save(map5_com, filename = "../_Tables_Figures/Figures/map_cl_combined.png", dpi = 1000)

map6_com <- tm_shape(huc_14040105) +
  tm_borders() +
  tm_shape(flowline_sp) +
  tm_lines(col = "AvgPredEC",
           style = "fixed", breaks = c(0, 200, 400, 600, 800, 1000, 1200),
           palette = rainbow2,
           title.col = "Conductivity (μScm)") +
  tm_shape(dat_median_Cl_sf) +
  tm_symbols(col = "Value", size = 0.5, shape = "agency_cd",
             palette = rainbow1,
             style = "fixed", breaks = c(0, 25, 50, 100, 200, 500, 1000, 2000, 10000, 55000),
             title.col = "Chloride (mg/L)", title.shape = "Agency") +
  tm_scale_bar(text.size = 1) +
  tm_compass(position = c("right", "top"), size = 4) +
  tm_layout(legend.only = TRUE, legend.bg.color = "white", frame = FALSE)

tmap_save(map6_com, filename = "../_Tables_Figures/Figures/map_cl_combined_legend.png", dpi = 1000)

p5_1 <- ggplot(dat_all_median %>% filter(Parameter %in% "Cl"), 
               aes(x = Value)) +
  geom_histogram(fill = "white", color = "black") +
  xlab("Chloride (mg/L)") +
  geom_vline(xintercept = 230, size = 2, linetype = "dashed") +
  scale_x_log10(label = comma) +
  theme_pubr()

dat_all_median_Cl <- dat_all_median %>%
  filter(Parameter %in% "Cl")

dat_all_median_Cl_r <- dat_all_median_Cl %>%
  mutate(agency_cd = "Combined")

dat_all_median_Cl2 <- bind_rows(dat_all_median_Cl, dat_all_median_Cl_r) %>%
  mutate(agency_cd = factor(agency_cd, 
                            levels = c("Combined", "SWCCD", "USGS",
                                       "AML", "LQD", "WQD")))

# ggsave(filename = "../_Tables_Figures/Figures/cl_hist.png", plot = p5_1, dpi = 1000, height = 5, width = 5)

p5_2 <- ggplot(dat_all_median_Cl2, aes(x = Value)) +
  geom_histogram(fill = "white", color = "black") +
  xlab("Chloride (mg/L)") +
  geom_vline(xintercept = 230, size = 2, linetype = "dashed") +
  scale_x_log10(label = comma_format(accuracy = 1)) +
  facet_wrap( ~ agency_cd, ncol = 3, scales = "free_y") +
  theme_pubr(base_size = 20) +
  theme(strip.background = element_rect(fill = "white"),
        strip.text = element_text(size = 20))

# ggsave(filename = "../_Tables_Figures/Figures/cl_hist_agency.png", plot = p5_2, dpi = 1000, height = 14, width = 20)

# Show the percentage < 230 of each category
dat_all_median_Cl2 %>%
  group_by(agency_cd) %>%
  summarize(Percentage = sum(Value < 230)/n() * 100)
# # A tibble: 6 x 2
#   agency_cd Percentage
#   <fct>          <dbl>
# 1 Combined       56.  
# 2 SWCCD          26.9 
# 3 USGS           72.7 
# 4 AML            15.4 
# 5 LQD            86.7 
# 6 WQD             7.69

### Calculate the summary data based on the median summary

### Conductivity
dat_median_SC <- dat_all_median %>%
  filter(Parameter %in% "SC") %>%
  left_join(flowline_bc2 %>%
              dplyr::select(COMID, StreamName), by = "COMID") 

dat_median_SC2 <- dat_median_SC %>%
  summarize(Sample_Site = n(),
            Minimum = min(Value),
            P10 = quantile(Value, 0.1),
            P25 = quantile(Value, 0.25),
            Median = median(Value),
            Maximum = max(Value)) %>%
  mutate(Group = "All")

dat_median_SC2_agency <- dat_median_SC %>%
  rename(Group = agency_cd) %>%
  group_by(Group) %>%
  summarize(Sample_Site = n(),
            Minimum = min(Value),
            P10 = quantile(Value, 0.1),
            P25 = quantile(Value, 0.25),
            Median = median(Value),
            Maximum = max(Value))

# By streams with all watershed
dat_median_SC_stream <- dat_median_SC %>%
  filter(StreamName %in% c("Killpecker Creek", "Bitter Creek")) %>%
  rename(Group = StreamName) %>%
  group_by(Group) %>%
  summarize(Sample_Site = n(),
            Minimum = min(Value),
            P10 = quantile(Value, 0.1),
            P25 = quantile(Value, 0.25),
            Median = median(Value),
            Maximum = max(Value))

# By streams with only USGS data
dat_median_SC_stream_USGS <- dat_median_SC %>%
  filter(agency_cd %in% "USGS") %>%
  filter(StreamName %in% c("Killpecker Creek", "Bitter Creek")) %>%
  rename(Group = StreamName) %>%
  group_by(Group) %>%
  summarize(Sample_Site = n(),
            Minimum = min(Value),
            P10 = quantile(Value, 0.1),
            P25 = quantile(Value, 0.25),
            Median = median(Value),
            Maximum = max(Value)) %>%
  mutate(Group = paste0(Group, "_USGS"))

dat_median_SC_wide <- bind_rows(dat_median_SC2, 
                             dat_median_SC2_agency,
                             dat_median_SC_stream,
                             dat_median_SC_stream_USGS) %>%
  pivot_longer(-Group, names_to = "Type", values_to = "Value") %>%
  spread(Group, Value) %>%
  select(Type, AML, LQD, SWCCD, USGS, WQD, All,
         `Killpecker Creek_USGS`, `Killpecker Creek`, 
         `Bitter Creek_USGS`, `Bitter Creek`) %>%
  mutate(Type = factor(Type, levels = c("Sample_Site",
                                        "Minimum",
                                        "P10", "P25", "Median",
                                        "Maximum"))) %>%
  arrange(Type)

# Calculate the sample size
write_csv(dat_median_SC_wide, "../_Tables_Figures/Tables/Table_SC.csv")

### Chloride
dat_median_Cl <- dat_all_median %>%
  filter(Parameter %in% "Cl") %>%
  left_join(flowline_bc2 %>%
              select(COMID, StreamName), by = "COMID") 

# All site and by agency
dat_median_Cl2 <- dat_median_Cl %>%
  summarize(Sample_Site = n(),
            Minimum = min(Value),
            P10 = quantile(Value, 0.1),
            P25 = quantile(Value, 0.25),
            Median = median(Value),
            Maximum = max(Value)) %>%
  mutate(Group = "All")

dat_median_Cl2_agency <- dat_median_Cl %>%
  rename(Group = agency_cd) %>%
  group_by(Group) %>%
  summarize(Sample_Site = n(),
            Minimum = min(Value),
            P10 = quantile(Value, 0.1),
            P25 = quantile(Value, 0.25),
            Median = median(Value),
            Maximum = max(Value))

# By streams with all watershed
dat_median_Cl_stream <- dat_median_Cl %>%
  filter(StreamName %in% c("Killpecker Creek", "Bitter Creek")) %>%
  rename(Group = StreamName) %>%
  group_by(Group) %>%
  summarize(Sample_Site = n(),
            Minimum = min(Value),
            P10 = quantile(Value, 0.1),
            P25 = quantile(Value, 0.25),
            Median = median(Value),
            Maximum = max(Value))

# By streams with USGS only
dat_median_Cl_stream_USGS <- dat_median_Cl %>%
  filter(agency_cd %in% "USGS") %>%
  filter(StreamName %in% c("Killpecker Creek", "Bitter Creek")) %>%
  rename(Group = StreamName) %>%
  group_by(Group) %>%
  summarize(Sample_Site = n(),
            Minimum = min(Value),
            P10 = quantile(Value, 0.1),
            P25 = quantile(Value, 0.25),
            Median = median(Value),
            Maximum = max(Value)) %>%
  mutate(Group = paste0(Group, "_USGS"))

dat_median_Cl_wide <- bind_rows(dat_median_Cl2, 
                             dat_median_Cl2_agency,
                             dat_median_Cl_stream,
                             dat_median_Cl_stream_USGS) %>%
  pivot_longer(-Group, names_to = "Type", values_to = "Value") %>%
  spread(Group, Value) %>%
  select(Type, AML, LQD, SWCCD, USGS, WQD, All,
         `Killpecker Creek_USGS`, `Killpecker Creek`, 
         `Bitter Creek_USGS`, `Bitter Creek`) %>%
  mutate(Type = factor(Type, levels = c("Sample_Site",
                                        "Minimum",
                                        "P10", "P25", "Median",
                                        "Maximum"))) %>%
  arrange(Type)

write_csv(dat_median_Cl_wide, "../_Tables_Figures/Tables/Table_Cl.csv")

### Calculate the background modeled conductivity and use
### the regression model to predict the Chloride concentration

flowline_bc3 <- flowline_bc2 %>% drop_na(AvgPredEC)

background_cond_summary <- flowline_bc3 %>%
  summarize(Sample_Site = n(),
            Minimum = min(AvgPredEC),
            P10 = quantile(AvgPredEC, 0.1),
            P25 = quantile(AvgPredEC, 0.25),
            P75 = quantile(AvgPredEC, 0.75),
            Median = median(AvgPredEC),
            Maximum = max(AvgPredEC)) %>%
  mutate(Group = "All")

### Background predicted median for Bitter Creek
background_Bitter_Killpecker_cond_summary <- flowline_bc3 %>%
  filter(StreamName %in% c("Bitter Creek", "Killpecker Creek")) %>%
  rename(Group = StreamName) %>%
  group_by(Group) %>%
  summarize(Sample_Site = n(),
            Minimum = min(AvgPredEC),
            P10 = quantile(AvgPredEC, 0.1),
            P25 = quantile(AvgPredEC, 0.25),
            P75 = quantile(AvgPredEC, 0.75),
            Median = median(AvgPredEC),
            Maximum = max(AvgPredEC))

background_cond <- bind_rows(background_cond_summary,
                             background_Bitter_Killpecker_cond_summary) %>%
  pivot_longer(-Group, names_to = "Type", values_to = "Value") %>%
  spread(Group, Value) %>%
  mutate(Type = factor(Type, levels = c("Sample_Site",
                                        "Minimum", "P10", "P25",
                                        "Median", "P75", "Maximum"))) %>%
  arrange(Type)

# Now apply different Cl regression model to predict the Cl values
background_cond2 <- background_cond %>%
  filter(!Type %in% "Sample_Site") %>%
  pivot_longer(-Type, names_to = "Group", values_to = "Value") %>%
  drop_na(Value) %>%
  mutate(SC = log10(Value)) %>%
  mutate(Combine_Cl = 10^predict(Combine_Cl_lm, .),
         Low_Cl =  10^predict(Low_Cl_lm, .),
         Mixed_Cl = 10^predict(Mixed_Cl_lm, .),
         High_Cl = 10^predict(High_Cl_lm, .))

background_cond3 <- background_cond2 %>%
  dplyr::select(Type, Group, Combine_Cl) %>%
  pivot_wider(names_from = "Group", values_from = "Combine_Cl") %>%
  bind_rows(background_cond %>%
              filter(Type %in% "Sample_Site"), .)



write_csv(background_cond, "../_Tables_Figures/Tables/Predicted_cond.csv")
write_csv(background_cond3, "../_Tables_Figures/Tables/Predicted_Cl.csv")

### Create Table 1 to count the sample site number and sample size

flowline_bc2_dat <- flowline_bc2 %>%
  st_set_geometry(NULL) %>%
  dplyr::select(COMID, StreamName) %>%
  distinct()

## SC

dat_all_SC_count <- dat_all_SC %>%
  left_join(flowline_bc2_dat, by = "COMID")

# Filter for Killpecker Creek
dat_all_SC_count_KC <- dat_all_SC_count %>%
  filter(StreamName %in% "Killpecker Creek")

# Filter for Bitter Creek
dat_all_SC_count_BC <- dat_all_SC_count %>%
  filter(StreamName %in% "Bitter Creek")

# Create a list
dat_all_SC_list <- list(KC = dat_all_SC_count_KC,
                        BC = dat_all_SC_count_BC,
                        Watershed = dat_all_SC_count)

# Design a function to count sample size and station number
count_fun <- function(x){
  x2 <- x %>%
    summarize(Sample_Size = n(),
              Station_Number = n_distinct(site_no, agency_cd, Latitude, Longitude))
}

# Count the number
SC_w <- map_dfr(dat_all_SC_list, count_fun, .id = "Stream") %>%
  pivot_longer(-Stream, names_to = "Type", values_to = "Count") %>%
  pivot_wider(names_from = "Stream", values_from = "Count")

# Filter for Oct to Jan and count the number
count_fun2 <- function(x){
  x2 <- x %>%
    mutate(Month = month(sample_dt)) %>%
    filter(Month %in% c(10, 11, 12, 1)) %>%
    summarize(Sample_Size = n(),
              Station_Number = n_distinct(site_no, agency_cd, Latitude, Longitude))
}

SC_w2 <- map_dfr(dat_all_SC_list, count_fun2, .id = "Stream") %>%
  rename(Oct_Jan_Sample_Size = Sample_Size,
         Oct_Jan_Station_Number = Station_Number) %>%
  pivot_longer(-Stream, names_to = "Type", values_to = "Count") %>%
  pivot_wider(names_from = "Stream", values_from = "Count")


# Filter for Mar to Aug and count the number
count_fun3 <- function(x){
  x2 <- x %>%
    mutate(Month = month(sample_dt)) %>%
    filter(Month %in% 3:8) %>%
    summarize(Sample_Size = n(),
              Station_Number = n_distinct(site_no, agency_cd, Latitude, Longitude))
}

SC_w3 <- map_dfr(dat_all_SC_list, count_fun3, .id = "Stream") %>%
  rename(Mar_Aug_Sample_Size = Sample_Size,
         Mar_Aug_Station_Number = Station_Number) %>%
  pivot_longer(-Stream, names_to = "Type", values_to = "Count") %>%
  pivot_wider(names_from = "Stream", values_from = "Count")

# Count the numbers by agency
SC_agency <- dat_all_SC_count %>%
  group_by(agency_cd) %>%
  summarize(Sample_Size = n(),
            Station_Number = n_distinct(site_no, Latitude, Longitude)) %>%
  ungroup() %>%
  pivot_longer(-agency_cd, names_to = "Type", values_to = "Count") %>%
  pivot_wider(names_from = "agency_cd", values_from = "Count")

SC_agency2 <- dat_all_SC_count %>%
  mutate(Month = month(sample_dt)) %>%
  filter(Month %in% c(10, 11, 12, 1)) %>%
  group_by(agency_cd) %>%
  summarize(Sample_Size = n(),
            Station_Number = n_distinct(site_no, Latitude, Longitude)) %>%
  ungroup() %>%
  rename(Oct_Jan_Sample_Size = Sample_Size,
         Oct_Jan_Station_Number = Station_Number) %>%
  pivot_longer(-agency_cd, names_to = "Type", values_to = "Count") %>%
  pivot_wider(names_from = "agency_cd", values_from = "Count")

SC_agency3 <- dat_all_SC_count %>%
  mutate(Month = month(sample_dt)) %>%
  filter(Month %in% 3:8) %>%
  group_by(agency_cd) %>%
  summarize(Sample_Size = n(),
            Station_Number = n_distinct(site_no, Latitude, Longitude)) %>%
  ungroup() %>%
  rename(Mar_Aug_Sample_Size = Sample_Size,
         Mar_Aug_Station_Number = Station_Number) %>%
  pivot_longer(-agency_cd, names_to = "Type", values_to = "Count") %>%
  pivot_wider(names_from = "agency_cd", values_from = "Count")

SC_agency_all <- bind_rows(SC_agency, SC_agency2, SC_agency3)
SC_w_all <- bind_rows(SC_w, SC_w2, SC_w3)

SC_count_table <- SC_agency_all %>%
  left_join(SC_w_all, by = "Type")

write_csv(SC_count_table, "../_Tables_Figures/Tables/Table_1_SC.csv")

# Combine the data


## Cl

dat_all_Cl_count <- dat_all %>%
  filter(Parameter %in% "Cl") %>%
  left_join(flowline_bc2_dat, by = "COMID")

# Filter for Killpecker Creek
dat_all_Cl_count_KC <- dat_all_Cl_count %>%
  filter(StreamName %in% "Killpecker Creek")

# Filter for Bitter Creek
dat_all_Cl_count_BC <- dat_all_Cl_count %>%
  filter(StreamName %in% "Bitter Creek")

# Create a list
dat_all_Cl_list <- list(KC = dat_all_Cl_count_KC,
                        BC = dat_all_Cl_count_BC,
                        Watershed = dat_all_Cl_count)

# Count the number
Cl_w <- map_dfr(dat_all_Cl_list, count_fun, .id = "Stream") %>%
  pivot_longer(-Stream, names_to = "Type", values_to = "Count") %>%
  pivot_wider(names_from = "Stream", values_from = "Count")
Cl_w2 <- map_dfr(dat_all_Cl_list, count_fun2, .id = "Stream") %>%
  rename(Oct_Jan_Sample_Size = Sample_Size,
         Oct_Jan_Station_Number = Station_Number) %>%
  pivot_longer(-Stream, names_to = "Type", values_to = "Count") %>%
  pivot_wider(names_from = "Stream", values_from = "Count")
Cl_w3 <- map_dfr(dat_all_Cl_list, count_fun3, .id = "Stream") %>%
  rename(Mar_Aug_Sample_Size = Sample_Size,
         Mar_Aug_Station_Number = Station_Number) %>%
  pivot_longer(-Stream, names_to = "Type", values_to = "Count") %>%
  pivot_wider(names_from = "Stream", values_from = "Count") 

### Count the numbers by agency
Cl_agency <- dat_all_Cl_count %>%
  group_by(agency_cd) %>%
  summarize(Sample_Size = n(),
            Station_Number = n_distinct(site_no, Latitude, Longitude)) %>%
  ungroup() %>%
  pivot_longer(-agency_cd, names_to = "Type", values_to = "Count") %>%
  pivot_wider(names_from = "agency_cd", values_from = "Count")

Cl_agency2 <- dat_all_Cl_count %>%
  mutate(Month = month(sample_dt)) %>%
  filter(Month %in% c(10, 11, 12, 1)) %>%
  group_by(agency_cd) %>%
  summarize(Sample_Size = n(),
            Station_Number = n_distinct(site_no, Latitude, Longitude)) %>%
  ungroup() %>%
  rename(Oct_Jan_Sample_Size = Sample_Size,
         Oct_Jan_Station_Number = Station_Number) %>%
  pivot_longer(-agency_cd, names_to = "Type", values_to = "Count") %>%
  pivot_wider(names_from = "agency_cd", values_from = "Count")

Cl_agency3 <- dat_all_Cl_count %>%
  mutate(Month = month(sample_dt)) %>%
  filter(Month %in% 3:8) %>%
  group_by(agency_cd) %>%
  summarize(Sample_Size = n(),
            Station_Number = n_distinct(site_no, Latitude, Longitude)) %>%
  ungroup() %>%
  rename(Mar_Aug_Sample_Size = Sample_Size,
         Mar_Aug_Station_Number = Station_Number) %>%
  pivot_longer(-agency_cd, names_to = "Type", values_to = "Count") %>%
  pivot_wider(names_from = "agency_cd", values_from = "Count")

Cl_agency_all <- bind_rows(Cl_agency, Cl_agency2, Cl_agency3)
Cl_w_all <- bind_rows(Cl_w, Cl_w2, Cl_w3)

Cl_count_table <- Cl_agency_all %>%
  left_join(Cl_w_all, by = "Type")

write_csv(Cl_count_table, "../_Tables_Figures/Tables/Table_1_Cl.csv")

