### This script cleans up and summarizes the data in Bitter Creek

# Clear working space
rm(list = ls())

# Load packages
library(tidyverse)
library(lubridate)
library(dataRetrieval)
library(sp)
library(sf)
library(rgdal)
library(readxl)
library(mapview)
library(nhdplusTools)
library(scales)
library(ggpubr)
library(tmap)
library(broom)

# Load the data
dat_all <- read_csv("../_Datasets/Output/data_all.csv")

# Filter for USGS values
dat_USGS <- dat_all %>%
  filter(agency_cd %in% "USGS", Parameter %in% "SC") %>%
  mutate(Year = year(sample_dt), Month = month(sample_dt)) %>%
  mutate(Group = case_when(
    Month %in% c(10, 11, 12, 1)      ~"Winter",
    Month %in% c(3, 4, 5, 6, 7, 8)   ~"Spring-Summer",
    TRUE                             ~"None"
  )) %>%
  mutate(WaterYear = ifelse(Month %in% c(10, 11, 12), Year + 1, Year))

# COunt unique site_no
dat_USGS %>%
  count(site_no) %>%
  arrange(desc(n))
# # A tibble: 143 x 2
#   site_no                  n
#   <chr>                <int>
# 1 USGS-09216565          198
# 2 USGS-09216545          149
# 3 USGS-09216562          108
# 4 USGS-09216750           77
# 5 USGS-09216880           75
# 6 USGS-09216576           60
# 7 USGS-09216810           57
# 8 USGS-09216950           37
# 9 USGS-09216574           19
# 10 USGS-411618108574001    14
# # ... with 133 more rows

# COunt unique site_no
dat_USGS %>%
  count(COMID) %>%
  arrange(desc(n))
# # A tibble: 88 x 2
#   COMID     n
#   <dbl> <int>
# 1 3390199   215
# 2 3390157   149
# 3 3387877   109
# 4 3387957    77
# 5 3387285    76
# 6 3388945    63
# 7 3387231    57
# 8 3387319    49
# 9 3387311    27
# 10 3388953    24
# # ... with 78 more rows

### Download the site parameter information to see if there are flow data
station_list <- dat_USGS %>%
  dplyr::select(site_no) %>%
  distinct() %>%
  mutate(site_no = str_remove(site_no, "USGS-"))

# Download the discharge data
discharge_site <- whatNWISdata(siteNumber = station_list$site_no, 
                               #service = "dv", 
                               parameterCd = "00060")

discharge_site2 <- discharge_site %>%
  filter(count_nu > 50)

# Download the flow data
discharge_data <- readNWISdv(siteNumbers = discharge_site2$site_no,
                             parameterCd = "00060")

discharge_data2 <- discharge_data %>%
  mutate(site_no = str_c("USGS-", site_no)) %>%
  rename(Flow_CFS = X_00060_00003) %>%
  mutate(Year = year(Date), Month = month(Date)) %>%
  left_join(tibble(Month = 1:12, Month.abb = month.abb), by = "Month") %>%
  mutate(Month.abb = factor(Month.abb, levels = c("Oct", "Nov", "Dec", "Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep")))

# Calculate the percentage of zero
# All
discharge_data2 %>%
  summarize(Percent = mean(Flow_CFS == 0) * 100)
#    Percent
# 1 31.27246

# Each site
discharge_data2 %>%
  group_by(site_no) %>%
  summarize(Percent = mean(Flow_CFS == 0) * 100)
# # A tibble: 6 x 2
#   site_no  Percent
#   <chr>      <dbl>
# 1 09216545    3.46
# 2 09216562   31.0 
# 3 09216565    4.93
# 4 09216576    0   
# 5 09216578   90.7 
# 6 09216750   61.3

# Add 0.01 to the data
discharge_data3 <- discharge_data2 %>%
  mutate(Flow_CFS = Flow_CFS + 0.01)

discharge_plot <- ggplot(discharge_data3, aes(x = Month.abb, y = Flow_CFS)) +
  geom_boxplot() +
  scale_y_continuous(name = "Flow (CFS)", label = comma,
                     trans = "log10") +
  xlab("Month") +
  theme_bw(base_size = 12) +
  theme(panel.grid = element_blank(),
        axis.text.x = element_text(angle = 90, vjust = -0.1))

discharge_plot2 <- ggplot(discharge_data3, aes(x = Month.abb, y = Flow_CFS)) +
  geom_boxplot() +
  scale_y_continuous(name = "Flow (CFS)", label = comma,
                     trans = "log10") +
  facet_wrap(~ site_no, nrow = 2) +
  xlab("Month") +
  theme_bw(base_size = 12) +
  theme(panel.grid = element_blank(),
        axis.text.x = element_text(angle = 90, vjust = -0.1))

# ggsave("../_Tables_Figures/Figures/Flow_USGS_all_box1.png", discharge_plot, width = 6, height = 6)
# ggsave("../_Tables_Figures/Figures/Flow_USGS_all_box2.png", discharge_plot2, width = 8, height = 6)

discharge_plot_noZero <- ggplot(discharge_data2, aes(x = Month.abb, y = Flow_CFS)) +
  geom_boxplot() +
  scale_y_continuous(name = "Flow (CFS)", label = comma,
                     trans = "log10") +
  xlab("Month") +
  theme_bw(base_size = 12) +
  theme(panel.grid = element_blank(),
        axis.text.x = element_text(angle = 90, vjust = -0.1))

discharge_plot2_noZero <- ggplot(discharge_data2, aes(x = Month.abb, y = Flow_CFS)) +
  geom_boxplot() +
  scale_y_continuous(name = "Flow (CFS)", label = comma,
                     trans = "log10") +
  facet_wrap(~ site_no, nrow = 2) +
  xlab("Month") +
  theme_bw(base_size = 12) +
  theme(panel.grid = element_blank(),
        axis.text.x = element_text(angle = 90, vjust = -0.1))

ggsave("../_Tables_Figures/Figures/Flow_USGS_all_box_six_noZero.png", discharge_plot_noZero, width = 6, height = 6)
ggsave("../_Tables_Figures/Figures/Flow_USGS_all_box_noZero.png", discharge_plot2_noZero, width = 8, height = 6)


# Create a boxplot for median monthly plot
dat_USGS_median <- dat_USGS %>%
  group_by(site_no, agency_cd, Year, Month, Group, Latitude, Longitude) %>%
  summarize(Value = median(Value)) %>%
  ungroup() %>%
  left_join(tibble(Month = 1:12, Month.abb = month.abb), by = "Month") %>%
  mutate(Month.abb = factor(Month.abb, levels = c("Oct", "Nov", "Dec", "Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep")))

dat_USGS_median %>%
  group_by(Group) %>%
  summarize(Value = median(Value))

dat_USGS_median2 <- dat_USGS %>%
  group_by(site_no, agency_cd, Month, Group, Latitude, Longitude) %>%
  summarize(Value = median(Value)) %>%
  ungroup() %>%
  left_join(tibble(Month = 1:12, Month.abb = month.abb), by = "Month") %>%
  mutate(Month.abb = factor(Month.abb, levels = c("Oct", "Nov", "Dec", "Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep")))

dat_USGS_median2 %>%
  group_by(Group) %>%
  summarize(Value = median(Value))

# dat_USGS %>%
#   filter(!Group %in% "None") %>%
#   arrange(site_no, agency_cd, Latitude, Longitude, Parameter, desc(sample_dt), desc(sample_tm)) %>%
#   group_by(Group, site_no, agency_cd, Latitude, Longitude, Parameter) %>%
#   summarize(Value = quantile(Value, probs = 0.5)) %>%
#   ungroup() %>%
#   group_by(Group) %>%
#   summarize(Value = quantile(Value, probs = 0.25))


ggplot(dat_USGS_median, aes(x = Month.abb, y = Value)) +
  geom_boxplot() +
  scale_y_log10(name = "Conductivity (μS/cm)") +
  xlab("Month") +
  ggtitle("Summarized by Year and Month. Plot the median.") +
  theme_bw(base_size = 12) +
  theme(panel.grid = element_blank(),
        axis.text.x = element_text(angle = 90, vjust = -0.1))

ggplot(dat_USGS_median2, aes(x = Month.abb, y = Value)) +
  geom_boxplot() +
  scale_y_log10(name = "Conductivity (μS/cm)") +
  xlab("Month") +
  ggtitle("Summarized by Month. Plot the median.") +
  theme_bw(base_size = 12) +
  theme(panel.grid = element_blank(),
        axis.text.x = element_text(angle = 90, vjust = -0.1))

### Calculate the sample size for each site
dat_USGS_count <- dat_USGS %>%
  group_by(site_no) %>%
  summarize(N = n(),
            Total_Y = n_distinct(WaterYear),
            N_yr = n()/n_distinct(WaterYear)) %>%
  arrange(desc(N))

dat_USGS_season <- dat_USGS %>%
  filter(!Group %in% "None") %>%
  group_by(site_no, Group) %>%
  summarize(N = n(),
            Total_Y = n_distinct(WaterYear),
            N_yr = n()/n_distinct(WaterYear)) %>%
  arrange(desc(N)) %>%
  pivot_wider(names_from = "Group", values_from = c("N", "Total_Y", "N_yr"), 
              values_fill = 0)

dat_USGS_all_count <- dat_USGS_count %>%
  left_join(dat_USGS_season, by = "site_no") %>%
  dplyr::select(site_no:N_yr, ends_with("Winter"), ends_with("Spring-Summer")) %>%
  mutate(across(.fns = function(x) ifelse(is.na(x), 0, x)))

dat_USGS_select <- dat_USGS_all_count %>%
  filter(Total_Y > 2, N_yr >= 2)

### Generate boxplot for all USGS data
dat_USGS_all <- dat_USGS %>%
  group_by(site_no) %>%
  # Only keep data with sample size >= 50
  filter(n() >= 50) %>%
  ungroup() %>%
  left_join(tibble(Month = 1:12, Month.abb = month.abb), by = "Month") %>%
  mutate(Month.abb = factor(Month.abb, levels = c("Oct", "Nov", "Dec", "Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep")))

box_p_USGS_all <- ggplot(dat_USGS_all, aes(x = Month.abb, y = Value)) +
  geom_boxplot() +
  scale_y_log10(name = "Conductivity (μS/cm)") +
  xlab("Month") +
  theme_bw(base_size = 12) +
  theme(panel.grid = element_blank(),
        axis.text.x = element_text(angle = 90, vjust = -0.1))

# Create a similar plot for n < 50
dat_USGS_all_reverse <- dat_USGS %>%
  group_by(site_no) %>%
  # Only keep data with sample size < 50
  filter(n() < 50) %>%
  ungroup() %>%
  left_join(tibble(Month = 1:12, Month.abb = month.abb), by = "Month") %>%
  mutate(Month.abb = factor(Month.abb, levels = c("Oct", "Nov", "Dec", "Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep")))

box_p_USGS_all_reverse <- ggplot(dat_USGS_all_reverse, aes(x = Month.abb, y = Value)) +
  geom_boxplot() +
  scale_y_log10(name = "Conductivity (μS/cm)") +
  xlab("Month") +
  theme_bw(base_size = 12) +
  theme(panel.grid = element_blank(),
        axis.text.x = element_text(angle = 90, vjust = -0.1))

### Generate a boxplot, inlcuding "USGS-09216545", "USGS-09216562", and "USGS-09216565",
box_example <- dat_USGS_all %>%
  filter(site_no %in% c("USGS-09216545", "USGS-09216562", "USGS-09216565")) %>%
  bind_rows(dat_USGS_all %>% mutate(site_no = "USGS (sample size >= 50 per site)")) %>%
  mutate(site_no = factor(site_no, c("USGS-09216545", "USGS-09216562", "USGS-09216565",
                                     "USGS (sample size >= 50 per site)"))) 

box_example_plot <- ggplot(box_example, aes(x = Month.abb, y = Value)) +
  geom_boxplot() +
  scale_y_log10(name = "Conductivity (μS/cm)") +
  facet_wrap( ~ site_no, ncol = 4) +
  xlab("Month") +
  theme_bw() +
  theme(panel.grid = element_blank(),
        axis.text.x = element_text(angle = 90, vjust = -0.1),
        strip.background = element_rect(fill = "white"))

ggsave("../_Tables_Figures/Figures/Conductivity_box_example.png", box_example_plot, width = 12, height = 5)

### Generate boxplot for the top 8 stations
dat_USGS_top <- dat_USGS %>%
  semi_join(dat_USGS_select, by = "site_no") %>%
  left_join(tibble(Month = 1:12, Month.abb = month.abb), by = "Month") %>%
  mutate(Month.abb = factor(Month.abb, levels = c("Oct", "Nov", "Dec", "Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep")))

dat_USGS_top2 <- dat_USGS_top %>%
  group_by(site_no) %>%
  nest()

dat_USGS_top3 <- dat_USGS_top2 %>%
  mutate(Box = map(data, function(x){
    p <- ggplot(x, aes(x = Month.abb, y = Value)) +
      geom_boxplot() +
      scale_y_log10() 
    return(p)
  })) 

box_p_top <- ggplot(dat_USGS_top, aes(x = Month.abb, y = Value)) +
  geom_boxplot() +
  scale_y_log10(name = "Conductivity (μS/cm)") +
  facet_wrap( ~ site_no, ncol = 4) +
  xlab("Month") +
  theme_bw() +
  theme(panel.grid = element_blank())

# ggsave("../_Tables_Figures/Figures/Conductivity_box.png", box_p_top, width = 12, height = 8)

# Create time series plot for
# 09216545, 09216562, 09216565, 09216572, 09216574, 09216576, and 09216750 

dat_USGS_top_re <- dat_USGS %>%
  left_join(tibble(Month = 1:12, Month.abb = month.abb), by = "Month") %>%
  mutate(Month.abb = factor(Month.abb, levels = c("Oct", "Nov", "Dec", "Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep"))) %>%
  filter(site_no %in% 
           c("USGS-09216545", "USGS-09216562", "USGS-09216565", "USGS-09216572", 
             "USGS-09216574", "USGS-09216576", "USGS-09216750", "USGS-09216580",
             "USGS-411153109030201", "USGS-411038109042101", "USGS-413454109133501")) %>%
  group_by(site_no) %>%
  mutate(Group = case_when(
    Group %in% "None"         ~as.character(Month.abb),
    TRUE                      ~Group
  )) %>%
  mutate(Group = recode(Group, "Feb" = "February",
                        "Spring-Summer" = "March-August",
                        "Sep" = "September",
                        "Winter" = "October-January")) %>%
  mutate(Group = factor(Group, levels = c("February", "March-August", "September", "October-January"))) %>%
  nest() %>%
  mutate(Plot = map2(data, site_no, function(x, y){
    p <- ggplot(data = x, aes(x = sample_dt, y = Value)) +
      geom_point(size = 2, aes(color = Group)) +
      scale_color_manual(values = c("February" = "#e41a1c",
                                    "March-August" = "#4daf4a",
                                    "September" = "#377eb8",
                                    "October-January" = "#984ea3")) +
      ggtitle(y) +
      xlab("") +
      ylab("Conductivity (μS/cm)") +
      theme_bw()    
    return(p)
  }))

# walk2(dat_USGS_top_re$site_no, dat_USGS_top_re$Plot,
#       ~ggsave(filename = paste0("../_Tables_Figures/Figures/", .x, ".png"), plot = .y))

### Create time-series plot for all sites with N >= 6
dat_USGS_all_count_6 <- dat_USGS_all_count %>% filter(N >= 6)

dat_USGS_top_re2 <- dat_USGS %>%
  left_join(tibble(Month = 1:12, Month.abb = month.abb), by = "Month") %>%
  mutate(Month.abb = factor(Month.abb, levels = c("Oct", "Nov", "Dec", "Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep"))) %>%
  semi_join(dat_USGS_all_count_6, by = "site_no") %>%
  group_by(site_no) %>%
  mutate(Group = case_when(
    Group %in% "None"         ~as.character(Month.abb),
    TRUE                      ~Group
  ))

p_N6 <- ggplot(data = dat_USGS_top_re2, aes(x = sample_dt, y = Value, color = Group)) +
  geom_point(size = 2) +
  scale_color_brewer(type = "qual", palette = "Set1") +
  scale_x_date(date_labels = "%Y-%m") +
  ggtitle("USGS sites with sample size >= 6") +
  xlab("") +
  ylab("Conductivity (μS/cm)") +
  facet_wrap(~site_no, ncol = 5, scales = "free") +
  theme_bw() 

ggsave(plot = p_N6, filename = "../_Tables_Figures/Figures/USGS_sites_N6.png", height = 10, width = 15, dpi = 300)

### Add predicted data

# Load the data 
pred_dat <- read_excel("../_Datasets/Bitter_Creek_Predicted_Background.xlsx")

pred_dat_USGS09216562 <- read_excel("../_Datasets/Bitter_Creek_AdditionalSite2_Predicted_Background.xlsx")

pred_dat_new <- read_excel("../_Datasets/Bitter_Creek_Additional_USGS_Locations_Predicted_Background.xlsx")

pred_dat_new2 <- pred_dat_new %>%
  rename(site_no = SiteID, Longitude = Long_DD, Latitude = Lat_DD)

pred_dat_new2_names <- str_replace(names(pred_dat_new2), "-", "_")

names(pred_dat_new2) <- pred_dat_new2_names

pred_dat <- bind_rows(pred_dat, pred_dat_USGS09216562, pred_dat_new2)

# Convert to long format
pred_dat2 <- pred_dat %>%
  dplyr::select(site_no, Latitude, Longitude, COMID, `0_Dec`:`15_Dec`) %>%
  pivot_longer(cols = `0_Dec`:`15_Dec`, names_to = "Type", values_to = "Value") %>%
  separate(col = Type, into = c("Year", "Month"), sep = "_", convert = TRUE) %>%
  mutate(Year = Year + 2000) %>%
  left_join(tibble(
    Month = month.abb,
    Month_Num = 1:12
  ),
  by = "Month") %>%
  arrange(site_no, Month_Num)

# Prepare add on data to the original timeseries plot

# Get the year and month from dat_USGS_top_re
dat_USGS_top_re2 <- dat_USGS_top_re %>%
  mutate(Begin_Date = map_chr(data, ~.x$sample_dt %>% min() %>% as.character()),
         End_Date = map_chr(data, ~.x$sample_dt %>% max() %>% as.character())) %>%
  mutate(across(ends_with("Date"), .fns = ymd)) 

pred_dat2_summary <- pred_dat2 %>%
  group_by(site_no) %>%
  summarize(Minimum_SC = min(Value, na.rm = TRUE),
            Maximum_SC = max(Value, na.rm = TRUE),
            Range = Maximum_SC - Minimum_SC)

# write_csv(pred_dat2_summary, "Output/USGS_Predicted_Range.csv")

# Join the data
pred_dat3 <- pred_dat2 %>%
  group_by(site_no) %>%
  nest() %>%
  rename(pred_data = data)

dat_USGS_top_re3 <- dat_USGS_top_re2 %>%
  left_join(pred_dat3, by = "site_no") %>%
  # Prepare the data
  mutate(pred_data2 = pmap(list(pred_data, Begin_Date, End_Date),
                           function(x, y ,z){
                             begin_year = year(y)
                             begin_month = month(y)
                             end_year = year(z)
                             end_month = month(z)
                             
                             # Create a sequence of year
                             year_seq <- begin_year:end_year
                             
                             # Get the length of year sequence
                             year_seq_len <- length(year_seq)
                             
                             # Get the differences of the last year
                             diff_y <- 2015 - end_year
                             
                             # Filter the years in x
                             x2 <- x %>%
                               # Create a new year column
                               mutate(New_Year = Year - diff_y)
                             
                             dat <- expand.grid(Year = year_seq, Month = 1:12)
                             dat2 <- dat %>%
                               mutate(Date = make_date(year = Year, month = Month)) %>%
                               filter(Date >= y, Date <= z)
                             dat3 <- dat2 %>%
                               left_join(x2, by = c("Year" = "New_Year", "Month" = "Month_Num"))
                             
                             return(dat3)
                           })) %>%
  # Create new plot
  mutate(Plot2 = map2(Plot, pred_data2, function(x, y){
    p <- x +
      # geom_point(data = y, aes(x = Date, y = Value, fill = as.factor(Month)), 
      #            shape = 23, color = "black", size = 2) +
      geom_ribbon(aes(ymin = min(y$Value), ymax = max(y$Value)),
                  fill = "grey70", alpha = 0.5) +
      scale_y_log10()
    return(p)
  }))

walk2(dat_USGS_top_re3$site_no, dat_USGS_top_re3$Plot2, 
      ~ggsave(filename = paste0("../_Tables_Figures/Figures/", .x, "_pred_recent.png"), plot = .y,
              width = 8, height = 6))

### Add the inverse of the flow to USGS-09216565

# Calculate the percentage of zero
mean(discharge_data2$Flow_CFS == 0) * 100
# [1] 31.27246

discharge_09216565 <- discharge_data2 %>%
  filter(site_no %in% "USGS-09216565") %>%
  #filter(Flow_CFS > 0) %>%
  # Calculate the inverse flow
  mutate(Flow_CFS = Flow_CFS + 0.1) %>%
  mutate(InFlow = 1/Flow_CFS) %>%
  mutate(SFlow = (InFlow - min(InFlow))/(max(InFlow) - min(InFlow)) * (3000 - 500) + 500) 

dat_09216565_1 <- dat_USGS_top_re3 %>%
  filter(site_no %in% "USGS-09216565") %>%
  pluck("data", 1) %>%
  complete(sample_dt = full_seq(sample_dt, period = 1)) %>%
  mutate(Group = case_when(
    Month %in% c(10, 11, 12, 1)      ~"October-January",
    Month %in% c(3, 4, 5, 6, 7, 8)   ~"March-August",
    Month %in% 2                     ~"February",
    Month %in% 9                     ~"September"
  ))

dat_09216565_2 <- dat_USGS_top_re3 %>%
  filter(site_no %in% "USGS-09216565") %>%
  pluck("pred_data2", 1) 

dat_09216565_1_1 <- dat_09216565_1 %>%
  left_join(discharge_09216565 %>% 
              select(site_no, Date, InFlow, SFlow), by = c("sample_dt" = "Date")) %>%
  mutate(Group = recode(Group, "Feb" = "February",
                               "Spring-Summer" = "March-August",
                               "Sep" = "September",
                               "Winter" = "October-January")) %>%
  mutate(Group = factor(Group, levels = c("February", "March-August", "September", "October-January")))

# # A linear model between InFlow and SFlow for transformation
fit <- lm(InFlow ~ SFlow, data = discharge_09216565)

convert_fun <- function(x){
  flow <- (1 - 0.1 * x)/x
  return(flow)
}

# Predict the Flow CFS based on SFlow value
pred_SFlow <- data.frame(
  SFlow = c(500, 550, 600, 700, 800, 900, 1000, 1500, 2000, 2500, 3000)
)

pred_SFlow2 <- pred_SFlow %>%
  mutate(InFlow = predict(fit, .)) %>%
  mutate(Flow_CFS = round(convert_fun(InFlow), 2))

plot_09216565_SFlow <- ggplot(data = dat_09216565_1_1, aes(x = sample_dt, y = Value)) +
  geom_point(size = 2, aes(color = Group)) +
  geom_line(aes(y = SFlow), color = "blue", alpha = 0.3) +
  # geom_point(data = dat_09216565_2, aes(x = Date, y = Value, fill = as.factor(Month)),
  #            shape = 23, color = "black", size = 2) +
  geom_ribbon(aes(ymin = min(dat_09216565_2$Value), ymax = max(dat_09216565_2$Value)),
              fill = "grey70", alpha = 0.5) +
  scale_y_log10(breaks = pred_SFlow2$SFlow,
                sec.axis = sec_axis(~., name = "1/CFS",
                                    breaks = pred_SFlow2$SFlow)) +
  scale_color_manual(values = c("February" = "#e41a1c",
                                "March-August" = "#4daf4a",
                                "September" = "#377eb8",
                                "October-January" = "#984ea3")) +
  ggtitle("USGS-09216565") +
  xlab("") +
  ylab("Conductivity (μS/cm)") +
  theme_bw()    

# ggsave(plot = plot_09216565_Inflow, "../Tables_Figures/Figures/plot_09216565_Inflow.png", width = 8, height = 6)
ggsave(plot = plot_09216565_SFlow, "../_Tables_Figures/Figures/plot_09216565_SFlow.png", width = 8, height = 6)

# Modified the second y-axis with the numbers in pred_SFlow2$Flow_CFS in Power Point
# The new file is called plot_09216565_SFlow_Updated.png

# Process the top data
dat_USGS_top_summary <-  dat_USGS %>%
  filter(site_no %in% 
           c("USGS-09216545", "USGS-09216562",
             "USGS-09216565", "USGS-09216572", "USGS-09216560",
             "USGS-09216574", "USGS-09216576", "USGS-09216750")) %>%
  group_by(site_no) %>%
  summarise(Start_Date = min(sample_dt), 
            End_Date = max(sample_dt),
            Longitude = unique(Longitude),
            Latitude = unique(Latitude))

# Filter for sites with records >= 100
dat_USGS_re <- dat_USGS %>%
  group_by(site_no) %>%
  filter(n() >= 100) %>%
  ungroup()

# Create month column plot the data as histograms
dat_USGS_re2 <- dat_USGS_re %>%
  mutate(Year = year(sample_dt), Month = month(sample_dt)) %>%
  left_join(tibble(Month = 1:12, Month.abb = month.abb), by = "Month") %>%
  mutate(Month.abb = factor(Month.abb, levels = c("Oct", "Nov", "Dec", "Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep")))

dat_USGS_re3 <- dat_USGS_re2 %>%
  group_by(site_no) %>%
  nest()

dat_USGS_re4 <- dat_USGS_re3 %>%
  mutate(Hist = map(data, function(x){
    p <- ggplot(x, aes(x = Value)) +
      geom_histogram() +
      scale_x_log10() +
      facet_wrap(~Month.abb, ncol = 4)
    return(p)
  })) %>%
  mutate(Dist = map(data, function(x){
    p <- ggplot(x, aes(x = Value)) +
      geom_density() +
      scale_x_log10() +
      facet_wrap(~Month.abb, ncol = 4)
    return(p)
  }))
  
# Create boxplot
dat_USGS_re5 <- dat_USGS_re4 %>%
  mutate(Box = map(data, function(x){
    p <- ggplot(x, aes(x = Month.abb, y = Value)) +
      geom_boxplot() +
      scale_y_log10() 
    return(p)
  })) 

# Create overall boxplot
box_p <- ggplot(dat_USGS_re2, aes(x = Month.abb, y = Value)) +
  geom_boxplot() +
  scale_y_log10(name = "Conductivity (μS/cm)") +
  facet_grid(. ~ site_no) +
  xlab("Month") +
  theme_bw(base_size = 18) +
  theme(panel.grid = element_blank(),
        axis.text.x = element_text(angle = 90, vjust = -0.1))

# ggsave("../_Tables_Figures/Figures/ConductivityUSUS_select_box.png", box_p, width = 10, height = 6)

# Download the daily flow data fot the three sites
usgs_id <- unique(dat_USGS_re2$site_no) %>% str_replace("USGS-", "")

flow <- readNWISdv(siteNumbers = usgs_id, parameterCd = "00060", startDate = min(dat_USGS_re2$sample_dt))

flow2 <- flow %>%
  unite(site_no, c(agency_cd, site_no), sep = "-") %>%
  rename(Flow_cfs = X_00060_00003)

# Join the flow data to the conductivity data
dat_USGS_re2_flow <- dat_USGS_re2 %>%
  left_join(flow2, by = c("site_no", "sample_dt" = "Date"))

scatter_p <- ggplot(dat_USGS_re2_flow, aes(x = Flow_cfs, y = Value)) +
  geom_smooth(method = "gam", se = FALSE) +
  geom_point(shape = 21, aes(fill = Month.abb), color = "black", size = 3) +
  xlab("Flow (cfs)") +
  scale_y_log10(name = "Conductivity (μS/cm)") +
  scale_fill_brewer(type = "qual", palette = "Paired") +
  facet_wrap(~ site_no, scales = "free") +
  theme_bw() +
  theme(panel.grid = element_blank(),
        strip.background = element_rect(fill = "white"))

ggsave("../_Tables_Figures/Figures/Conductivity_scatter.png", scatter_p, dpi = 1000, width = 8, height = 6)





  






