### This script cleans up and summarizes the data in Bitter Creek

# Clear working space
rm(list = ls())

# Load packages
library(tidyverse)
library(lubridate)
library(dataRetrieval)
library(sp)
library(sf)
library(rgdal)
library(readxl)
library(mapview)
library(nhdplusTools)
library(EnvStats)

### Load the data

# USGS data
USGS_wq <- read_excel("../_Datasets/USGS_SW_Chemistry.xlsx", guess_max = 100000)
USGS_site <- read_excel("../_Datasets/USGS_SW_Sites.xlsx", guess_max = 100000)

# AML: Abandoned Mine Lands Division 
AML_wq <- read_excel("../_Datasets/AML_SW_Chemistry.xlsx", guess_max = 10000, na = c("", "--"))
AML_site <- read_excel("../_Datasets/AML_Sites.xlsx")

# SWCCD: Sweetwater County Conservation District 
SWCCD_wq <- read_excel("../_Datasets/SWCCD_SW.xlsx", guess_max = 10000, na = c("", "NA"))

# LQD: Land Quality Division 
LQD_chloride <- read_excel("../_Datasets/LQD_SW_Chlorides.xlsx", guess_max = 10000)
LQD_field <- read_excel("../_Datasets/LQD_SW_Field.xlsx", guess_max = 10000)
LQD_site <- read_excel("../_Datasets/LQD_SW_Sites.xlsx", guess_max = 10000)

# WQD: Water Quality Division
WQD_wq <- read_excel("../_Datasets/WQD_SW_Chemistry2.xlsx", guess_max = 10000, na = c("", "NR", "---"))
WQD_site <- read_excel("../_Datasets/WQD_Sites.xlsx", guess_max = 10000)

### USGS

# Fix the parameter code
USGS_wq <- USGS_wq %>%
  mutate(parm_cd = str_pad(parm_cd, width = 5, pad = "0"))

# Prepare a table to show all the parameter code
USGS_par <- USGS_wq %>% 
  count(parm_cd) %>%
  # Join the parameter table from parameterCdFile
  left_join(parameterCdFile, by = c("parm_cd" = "parameter_cd"))

# Find the target parameters:

# Specific conductance: 00095
# Hardness: 00900
# Carbonate: 00445
# Alkalinity: 
# Bicarbonate: 00440
# Sulfate: 00945
# Chloride: 00940
# Calcium: 00915
# Magnesium: 00925
# Sodium: 00930
# Potassium: 00935
# TSS: 00530
# Fe, Total: 01045
# Fe, Dissolved: 01046
# Al, Total: 01105
# Al, Dissolved: 01106
# DO: 00300
# TP: 00665
# Nitrate + Nitrite: 00630
# Fecal (0.7 micron): 31625
# pH: 00400
# Temperature: 00010

# Filter the dataset by these parameters
USGS_wq2 <- USGS_wq %>%
  filter(parm_cd %in% c("00095", "00900", "00445", "00440", "00945", "00940", "00915", "00925", 
                        "00930", "00935", "00530", "01045", "01046", "01105", "01106", "00300", 
                        "00665", "00630", "31625", "00400", "00010"))

USGS_wq3 <- USGS_wq2 %>%
  left_join(parameterCdFile, by = c("parm_cd" = "parameter_cd")) %>%
  dplyr::select(site_no, agency_cd, sample_dt, sample_tm, parameter_nm, parameter_units, result_va) 

# Check the combination of parameter name and unit
USGS_wq_unit <- USGS_wq3 %>%
  count(parameter_nm, parameter_units)

write_csv(USGS_wq_unit, "../_Datasets/Output/USGS_wq_unit.csv")

# Manually edit the table to add the abbreviation name and conversion factor, and then load the data
USGS_wq_unit2 <- read_csv("../_Datasets/Output/USGS_wq_unit2.csv")

USGS_wq4 <- USGS_wq3 %>%
  left_join(USGS_wq_unit2, by = c("parameter_nm", "parameter_units")) %>%
  # Unit conversion
  mutate(Value = result_va * Convert) %>%
  select(-parameter_nm, -parameter_units, -result_va, -Convert, -n, -Unit)

# Join latitude and longitude to USGS_wq4
USGS_wq5 <- USGS_wq4 %>%
  left_join(USGS_site %>% select(site_no, Latitude = dec_lat_va, Longitude = dec_long_va), 
            by = c("site_no")) %>%
  mutate(sample_tm = format(sample_tm, format = "%H:%M:%S")) %>%
  mutate(sample_dt = as.Date(sample_dt)) %>%
  mutate(site_no = paste0("USGS-", site_no))

# There are some sites have no latitude and longitude
# Find those coordinates using data retrieval
USGS_wq5_nolatlong <- USGS_wq5 %>%
  ungroup() %>%
  select(site_no, Longitude, Latitude) %>%
  distinct() %>%
  filter(is.na(Longitude), is.na(Latitude)) %>%
  mutate(site_no = str_replace(site_no, "USGS-", ""))

USGS_sites_update <- whatNWISsites(sites = USGS_wq5_nolatlong$site_no)
  
USGS_wq5_nolatlong2 <- USGS_wq5_nolatlong %>%
  left_join(USGS_sites_update %>%
              dplyr::select(site_no, dec_long_va, dec_lat_va),
            by = "site_no") %>%
  mutate(site_no = paste0("USGS-", site_no))

USGS_wq6 <- USGS_wq5 %>%
  left_join(USGS_wq5_nolatlong2 %>%
              select(site_no, dec_long_va, dec_lat_va), by = "site_no") %>%
  mutate(Longitude = ifelse(is.na(Longitude), dec_long_va, Longitude),
         Latitude = ifelse(is.na(Latitude), dec_lat_va, Latitude)) %>%
  select(-dec_long_va, -dec_lat_va) %>%
  rename(Parameter = Abbr) %>%
  drop_na(Value)

# Check if the latitude and longitude looks correct

summary(USGS_wq6$Latitude)
#  Min. 1st Qu.  Median    Mean 3rd Qu.    Max. 
# 41.06   41.40   41.54   41.47   41.60   41.99

summary(USGS_wq6$Longitude)
#   Min. 1st Qu.  Median    Mean 3rd Qu.    Max. 
# -109.4  -109.3  -109.1  -109.1  -109.0  -108.3

### Abandoned Mine Lands Division
AML_wq2 <- AML_wq %>%
  dplyr::select(site_no = `Location ID`, sample_dt = `Date Sampled`,
                Cl = `Chloride, Total_(mg/L)`,  SC = `Field Conductivity (µS/cm)`,
                NOx = `Nitrogen, Nitrate & Nitrite_(mg/L)`, TSS = `Suspended Solids, Total (mg/L)`,
                pH = `pH                      (std Units)`, Temperature = `Temperature (°C)`)

# Join AML_site to AML
AML_wq3 <- AML_wq2 %>%
  left_join(AML_site %>% select(site_no = `Monitoring site`, Latitude, Longitude), by = "site_no") %>%
  mutate(agency_cd = "AML") %>%
  mutate(sample_tm = format(sample_dt, format = "%H:%M:%S")) %>%
  mutate(sample_dt = as.Date(sample_dt)) %>%
  mutate(across(Cl:Temperature, .fns = as.numeric))

# Check if the latitude and longitude looks correct

summary(AML_wq3$Latitude)
#  Min. 1st Qu.  Median    Mean 3rd Qu.    Max. 
# 41.56   41.57   41.59   41.58   41.59   41.60

summary(AML_wq3$Longitude)
#   Min. 1st Qu.  Median    Mean 3rd Qu.    Max. 
# -109.3  -109.2  -109.2  -109.2  -109.2  -109.1

# Convert to long format
AML_wq4 <- AML_wq3 %>%
  pivot_longer(cols = Cl:Temperature, names_to = "Parameter", values_to = "Value") %>%
  drop_na(Value)

### Sweetwater County Conservation District 
SWCCD_wq2 <- SWCCD_wq %>%
  dplyr::select(site_no = Site_ID, sample_dt = Date, sample_tm = `Time_hr:min`, 
                Ca = `Ca_mg/L`, Cl = `Cl_mg/L`, CO3 = `CO3_mg/L`,
                HCO3 = `HCO3_mg/L`, K = `K_mg/L`, Mg = `Mg_mg/L`,
                Na = `Sodium_mg/L`, SO4 = `SO4_mg/L`,
                SC = `Field_Condustivity_umhos/cm`,
                Fecal = `Fecal_Coliform_col/100mL`, TP = `Total_Phorsphorus_as_P_mg/L`,
                TSS = `TSS_mg/L`, Hardness = `Hardness_as_CaCO3_mg/L`, DO = `Field_DO_mg/L`,
                pH = Field_pH_su,
                Latitude = Latitude_WGS84_degrees, Longitude = Longitude_WGS84_degrees)

# Back to the main dataset. We can drop Alkalinity for now
SWCCD_wq3 <- SWCCD_wq2 %>% 
  mutate(agency_cd = "SWCCD") %>%
  mutate(sample_dt = as.Date(sample_dt), 
         sample_tm = format(sample_dt, format = "%H:%M:%S")) %>%
  drop_na(Latitude)

# Define a function to deal with values below the detection limit
detect_fun <- function(x){
  x2 <- str_replace(x, "<", "")
  x3 <- as.numeric(x2)
  x4 <- x3 * 0.5
  x5 <- as.character(x4)
  return(x5)
}

SWCCD_wq4 <- SWCCD_wq3 %>%
  mutate(across(Ca:pH, .fns = function(x) ifelse(str_detect(x, "<"), detect_fun(x), x))) %>%
  mutate(across(Ca:pH, .fns = as.numeric))

# Fix coordinates

# Check if the latitude and longitude look correct
summary(SWCCD_wq4$Latitude)
#  Min. 1st Qu.  Median    Mean 3rd Qu.    Max. 
# 41.23   41.57   41.60   41.61   41.66   41.97

summary(SWCCD_wq4$Longitude)
#   Min. 1st Qu.  Median    Mean 3rd Qu.    Max. 
# -109.4  -109.2  -109.2  -105.9  -109.0   109.1

SWCCD_wq5 <- SWCCD_wq4 %>%
  mutate(Longitude = ifelse(Longitude > 0, Longitude * -1, Longitude))

summary(SWCCD_wq5$Longitude)
#   Min. 1st Qu.  Median    Mean 3rd Qu.    Max. 
# -109.4  -109.2  -109.2  -109.1  -109.0  -108.5

# Convert to long format
SWCCD_wq6 <- SWCCD_wq5 %>%
  pivot_longer(cols = Ca:pH, names_to = "Parameter", values_to = "Value") %>%
  drop_na(Value)

### LQD data

LQD_CL <- LQD_chloride %>%
  select(site_no = SAMP_STATION_NAME, sample_dt = SAMP_DATE, PARAMETER_NAME, PARAMETER_VALUE) %>%
  # Change all parameter name to Cl
  mutate(PARAMETER_NAME = "Cl_mgl") %>%
  group_by(site_no, sample_dt, PARAMETER_NAME) %>%
  filter(PARAMETER_VALUE > 0) %>%
  summarize(PARAMETER_VALUE = mean(PARAMETER_VALUE, na.rm = TRUE)) %>%
  ungroup()

LQD_field2 <- LQD_field %>%
  select(site_no = SAMP_STATION_NAME, sample_dt = SAMP_DATE, PARAMETER_NAME, PARAMETER_VALUE) %>%
  group_by(site_no, sample_dt, PARAMETER_NAME) %>%
  filter(PARAMETER_VALUE > 0) %>%
  summarize(PARAMETER_VALUE = mean(PARAMETER_VALUE, na.rm = TRUE)) %>%
  ungroup()

# Combine data
LQD_field3 <- LQD_field2 %>%
  bind_rows(LQD_CL) %>%
  filter(!PARAMETER_NAME %in% "FIELD TDS") %>%
  spread(PARAMETER_NAME, PARAMETER_VALUE) %>%
  rename(Cl = Cl_mgl, DO = `FIELD DO`, pH = `FIELD PH`, SC = `FIELD SP CONDUCTANCE AT 25 C`,
         TSS = `FIELD TSS`, Temperature = `FIELD WATER TEMP`)

LQD_combine <- LQD_field3 %>%
  left_join(LQD_site %>%
              select(site_no = SAMP_STATION_NAME, Latitude = LAT, Longitude = LONG), by = "site_no") %>%
  mutate(agency_cd = "LQD") %>%
  mutate(sample_tm = format(sample_dt, format = "%H:%M:%S")) %>%
  mutate(sample_dt = as.Date(sample_dt))

# Check if longitude and latitude look correct
summary(LQD_combine$Longitude)
#   Min. 1st Qu.  Median    Mean 3rd Qu.    Max. 
# -109.2  -108.8  -108.7  -108.8  -108.6  -108.6

summary(LQD_combine$Latitude)
#  Min. 1st Qu.  Median    Mean 3rd Qu.    Max. 
# 41.52   41.60   41.72   41.69   41.77   41.86

# Convert to long format
LQD_combine2 <- LQD_combine %>%
  pivot_longer(cols = Cl:Temperature, names_to = "Parameter", values_to = "Value") %>%
  drop_na(Value)

### WQD data

WQD_wq2 <- WQD_wq %>%
  mutate(sample_dt = as.Date(DateTime), sample_tm = DateTime) %>%
  mutate(Alkalinity = as.numeric(`Alkalinity (mg/L)`), 
         HCO3 = Alkalinity * 1.22) %>% 
  select(site_no = Station, sample_dt, sample_tm, Cl = `Cl (mg/L)`, SO4 = `SO4 (mg/L)`,
         HCO3, SC = `SC (µmho/cm)`, Ca = `Ca (mg/L)`, Mg = `Mg (mg/L)`, K = `K (mg/L)`,
         Na = `Na (mg/L)`, pH, Temperature = `Temp (⁰C)`, DO = `DO (mg/L)`)   %>%
  mutate(across(Cl:DO, .fns = as.numeric)) %>%
  left_join(WQD_site %>% select(site_no = `Site Code`, Latitude, Longitude), by = "site_no") %>%
  mutate(agency_cd = "WQD") %>%
  mutate(sample_tm = format(sample_dt, format = "%H:%M:%S")) %>%
  mutate(sample_dt = as.Date(sample_dt)) %>%
  # Drop the records without coordinates
  drop_na(Latitude)

# Check if longitude and latitude look correct
summary(WQD_wq2$Longitude)
#   Min. 1st Qu.  Median    Mean 3rd Qu.    Max. 
# -109.3  -109.2  -109.2  -109.2  -109.2  -108.6

summary(WQD_wq2$Latitude)
#  Min. 1st Qu.  Median    Mean 3rd Qu.    Max. 
# 41.47   41.59   41.59   41.59   41.63   41.67

# Convert to long format
WQD_wq3 <- WQD_wq2 %>%
  pivot_longer(cols = Cl:DO, names_to = "Parameter", values_to = "Value") %>%
  drop_na(Value)

### Combine all datasets
data_all <- bind_rows(
  USGS_wq6,
  AML_wq4,
  SWCCD_wq6,
  LQD_combine2,
  WQD_wq3
)

write_csv(data_all, "../_Datasets/Output/data_raw.csv")

# Calculate the percentage of zero and negative
data_all_zero_neg <- data_all %>%
  group_by(Parameter) %>%
  summarize(Percent = mean(Value <= 0))

data_all_zero_neg_agency <- data_all %>%
  group_by(agency_cd, Parameter) %>%
  summarize(Percent = mean(Value <= 0))

var_levels <- c("SC", "Hardness", "SO4", "Cl",
                "Ca", "Mg", "Na", "K", "TSS", "Fe_T",
                "Fe_D", "Al_T", "Al_D", "DO", "TP", "NOx", "Fecal",
                "pH", "Temperature", "HCO3", "CO3")

data_all_zero_neg <- data_all_zero_neg %>%
  mutate(Parameter = factor(Parameter, levels = var_levels)) %>%
  arrange(Parameter)

data_all_zero_neg_agency <- data_all_zero_neg_agency %>%
  mutate(Parameter = factor(Parameter, levels = var_levels)) %>%
  arrange(agency_cd, Parameter)

# Drop zero and NA for now
data_all2 <- data_all %>%
  filter(Value > 0)

# Now calculate the average if site_no, agency_cd, sample_dt, sample_tm,
# Parameter, Value, Latitude, Longitude are the same
data_all3 <- data_all2 %>%
  group_by(site_no, agency_cd, sample_dt, sample_tm, Parameter, Latitude, Longitude) %>%
  summarize(Value = mean(Value))

# Calculate alkalinity and SO4 + HCO3

# Alkalinity is calculated as HCO3/1.22
data_all_alkalinity <- data_all3 %>%
  filter(Parameter %in% "HCO3") %>%
  mutate(Parameter = "Alkalinity", Value = Value/1.22)

# SO4 + HCO3 is calculated as the sum of SO4 and HOC3, but both 
# variables are not NA
data_all_SO4_HCO3 <- data_all3 %>%
  # Calculate Alkalinity from HCO3
  filter(Parameter %in% c("SO4", "HCO3")) %>%
  spread(Parameter, Value) %>%
  mutate(Parameter = "SO4_HCO3", Value = SO4 + HCO3) %>%
  drop_na(Value) %>%
  select(-SO4, -HCO3)

data_all4 <- data_all3 %>%
  bind_rows(data_all_alkalinity, data_all_SO4_HCO3)

# Re-level the Parameter
var_levels2 <- c("SC", "Hardness", "Alkalinity", "SO4", "Cl", "SO4_HCO3",
                "Ca", "Mg", "Na", "K", "TSS", "Fe_T",
                "Fe_D", "Al_T", "Al_D", "DO", "TP", "NOx", "Fecal",
                "pH", "Temperature", "HCO3", "CO3")

data_all5 <- data_all4 %>%
  mutate(Parameter = factor(Parameter, levels = var_levels2))

# Calculate summary statistics for data_all5
data_summary_all5 <- data_all5 %>%
  group_by(Parameter) %>%
  summarize(Min = min(Value), 
            Per10 = quantile(Value, probs = 0.1),
            Per25 = quantile(Value, probs = 0.25),
            Per50 = quantile(Value, probs = 0.5),
            Per75 = quantile(Value, probs = 0.75),
            Max = max(Value),
            Mean = mean(Value),
            SD = sd(Value),
            Geomean = geoMean(Value),
            N = n(),
            Site = n_distinct(site_no, agency_cd, Latitude, Longitude))

# Now deal with outliers

# Create a label to show the values that are above mean + 5 sd
data_all6 <- data_all5 %>%
  group_by(Parameter) %>%
  mutate(Outlier = ifelse(Value >= mean(Value) + sd(Value) * 5, "Yes", "No"))

data_all6_count <- data_all6 %>%
  count(Parameter, Outlier) %>%
  spread(Outlier, n, fill = 0)

data_all7 <- data_all6 %>% filter(Outlier %in% "No")

# A function to generate the summary
summary_fun_a <- function(dat, probs){
  dat2 <- dat %>%
    arrange(site_no, agency_cd, Latitude, Longitude, Parameter, desc(sample_dt), desc(sample_tm)) %>%
    group_by(site_no, agency_cd, Latitude, Longitude, Parameter) %>%
    summarize(Value = quantile(Value, probs = probs)) %>%
    ungroup()
  return(dat2)
}

summary_fun_b <- function(dat, probs){
  dat2 <- dat %>%
    mutate(Month = month(sample_dt)) %>%
    mutate(Group = case_when(
      Month %in% 3:8                   ~"Spring-Summer",
      Month %in% c(10, 11, 12, 1)      ~"Winter",
      Month %in% c(2, 9)               ~"Other",
      TRUE                             ~NA_character_
    )) %>%
    filter(!Group %in% "Other") %>%
    arrange(site_no, agency_cd, Latitude, Longitude, Parameter, desc(sample_dt), desc(sample_tm)) %>%
    group_by(Group, site_no, agency_cd, Latitude, Longitude, Parameter) %>%
    summarize(Value = quantile(Value, probs = probs)) %>%
    ungroup()
  return(dat2)
}

calculate <- function(dat, ...){
  dat2 <- dat %>%
    group_by(...) %>%
    summarize(Min = min(Value), 
              Per10 = quantile(Value, probs = 0.1),
              Per25 = quantile(Value, probs = 0.25),
              Per50 = quantile(Value, probs = 0.5),
              Per75 = quantile(Value, probs = 0.75),
              Max = max(Value),
              Mean = mean(Value),
              Geomean = geoMean(Value),
              N = n(),
              Site = n_distinct(site_no, agency_cd, Latitude, Longitude)) %>%
    ungroup()
}




### Calculate the summary statistics for data_all7
data_summary_all7 <- data_all7 %>% calculate(Parameter)

# A version showing summary statistics by agency
data_all6_count_agency <- data_all6 %>%
  count(agency_cd, Parameter, Outlier) %>%
  spread(Outlier, n, fill = 0) %>%
  arrange(agency_cd, Parameter) %>%
  select(agency_cd, Parameter, No, Yes)

data_summary_all7_agency <- data_all7 %>% calculate(agency_cd, Parameter)

# Combine data_summary_all7_agency and data_summary_all7
data_summary_all7_combined <- data_summary_all7_agency %>%
  bind_rows(data_summary_all7 %>%
              mutate(agency_cd = "Combined"))

write_csv(data_summary_all7_combined, "../_Tables_Figures/Tables/Table_A4.csv")

# Consider different seasons
data_all7_s <- data_all7 %>% 
  mutate(Month = month(sample_dt)) %>%
  mutate(Group = case_when(
    Month %in% 3:8                   ~"Spring-Summer",
    Month %in% c(10, 11, 12, 1)      ~"Winter",
    Month %in% c(2, 9)               ~"Other",
    TRUE                             ~NA_character_
  )) %>%
  filter(!Group %in% "Other") %>%
  ungroup()

data_summary_all7_s <- data_all7_s %>% calculate(Group, Parameter)

data_summary_all7_agency_s <- data_all7_s %>%
  calculate(Group, agency_cd, Parameter)

# Combine data_summary_all7_agency_s and data_summary_all7_s
data_summary_all7_s_combined <- data_summary_all7_agency_s %>%
  bind_rows(data_summary_all7_s %>%
              mutate(agency_cd = "Combined")) %>%
  mutate(agency_cd = factor(agency_cd, levels = c("AML", "LQD", "SWCCD", "USGS", "WQD", "Combined"))) %>%
  arrange(Group, agency_cd, Parameter)

write_csv(data_summary_all7_s_combined, "../_Tables_Figures/Tables/Table_A5.csv")

### A version showing the 50th percentile data
data_all7_50th <- data_all7 %>%
  summary_fun_a(probs = 0.5)

data_summary_all7_50th <- data_all7_50th %>%
  calculate(Parameter)

data_summary_all7_agency_50th <- data_all7_50th %>%
  calculate(agency_cd, Parameter) %>%
  arrange(agency_cd, Parameter) %>%
  ungroup()

### A version showing the 50th percentile data for different seasons
data_all7_50th_s <- data_all7 %>%
  summary_fun_b(probs = 0.5)

data_summary_all7_50th_s <- data_all7_50th_s %>%
  calculate(Group, Parameter)

data_summary_all7_agency_50th_s <- data_all7_50th_s %>%
  calculate(Group, agency_cd, Parameter) %>%
  arrange(Group, agency_cd, Parameter) %>%
  ungroup()

# # Review the 10th and 25th percentile
# SC_list <- list(data_summary_all7_50th,
#                 data_summary_all7_agency_50th)
# 
# SC_list2 <- SC_list %>%
#   map_dfr(function(x){
#     x2 <- x %>%
#       filter(Parameter %in% "SC") %>%
#       mutate(DIff = Per25 - Per10)
#     return(x2)
#   })
# 
# 
# SC_list3 <- list("Median" = data_summary_all7_agency_50th %>%
#                    filter(agency_cd %in% "USGS"),
#                 "Median_S" = data_summary_all7_agency_50th_s %>%
#                    filter(agency_cd %in% "USGS"),
#                 "Multiple" = data_summary_all7_agency %>%
#                    filter(agency_cd %in% "USGS"),
#                 "Multiple_S" = data_summary_all7_agency_s %>%
#                    filter(agency_cd %in% "USGS"))
# 
# SC_list4 <- SC_list3 %>%
#   map_dfr(function(x){
#     x2 <- x %>%
#       filter(Parameter %in% "SC") %>%
#       mutate(DIff = Per25 - Per10)
#     return(x2)
#   }, .id = "Data") %>%
#   mutate(Name = case_when(
#     is.na(Group) & Data %in% "Median"                  ~"All",
#     Group %in% "Spring-Summer" & Data %in% "Median_S"  ~"Mar-Aug",
#     Group %in% "Winter" & Data %in% "Median_S"         ~"Oct-Jan",
#     is.na(Group) & Data %in% "Multiple"                  ~"All-m",
#     Group %in% "Spring-Summer" & Data %in% "Multiple_S"  ~"Mar-Aug-m",
#     Group %in% "Winter" & Data %in% "Multiple_S"         ~"Oct-Jan-m",
#   )) %>%
#   select(Name, P10 = Per10, P25 = Per25) %>%
#   pivot_longer(-Name, names_to = "Centile", values_to = "Value") %>%
#   mutate(Centile = str_remove(Centile, "P")) %>%
#   mutate(Centile = str_c(Centile, "th")) %>%
#   mutate(Name = factor(Name, levels = c("All",
#                                         "Mar-Aug",
#                                         "Oct-Jan",
#                                         "All-m",
#                                         "Mar-Aug-m",
#                                         "Oct-Jan-m"))) %>%
#   mutate(Data = ifelse(str_detect(Name, "-m"), "USGS Multiple Samples", "USGS Median Station Values")) %>%
#   mutate(Name = str_remove(Name, "-m"))
# 
# p <- ggplot(SC_list4, aes(Name, y = Value, shape = Centile)) +
#   geom_point(size = 3, position = position_dodge(1)) +
#   scale_y_continuous(name = "Conductivity (μS/cm)",
#                      limits = c(0, 1300),
#                      breaks = seq(0, 1300, by = 100)) +
#   xlab("") +
#   facet_grid(. ~ Data) +
#   theme_bw(base_size = 20) +
#   theme(legend.position = "top",
#         panel.grid = element_blank(),
#         strip.background = element_rect(fill = "white"))
# 
# ggsave("Output/Compare_Adjusted_Multiple_SC.png", plot = p, dpi = 1000, width = 8, height = 6)


### Save output
write_csv(data_summary_all7_50th, "../_Tables_Figures/Tables/Summary_50th.csv")
write_csv(data_summary_all7_agency_50th, "../_Tables_Figures/Tables/Table_A6.csv")
write_csv(data_summary_all7_50th_s, "../_Tables_Figures/Tables/Summary_50th_Season.csv")
write_csv(data_summary_all7_agency_50th_s, "../_Tables_Figures/Tables/Table_A7.csv")

### Get the COMID using the get_flowline_index function
site_all <- data_all7 %>%
  ungroup() %>%
  select(site_no, agency_cd, Latitude, Longitude) %>%
  distinct()

# Convert to sf object
site_all_sf <- site_all %>%
  st_as_sf(coords = c("Longitude", "Latitude"), crs = 4326, remove = FALSE)

# Get COMID
flowline <- readRDS("../_Datasets/GIS/BC_flowline.rds")

site_all_sf <- site_all_sf %>% st_transform(crs = st_crs(flowline))

site_all_sf2 <- get_flowline_index(flines = flowline, points = site_all_sf,
                                   search_radius = 0.1)

site_all2 <- site_all %>% 
  bind_cols(site_all_sf2) %>%
  select(-id, -REACHCODE, -REACH_meas, -offset)

data_all8 <- data_all7 %>%
  left_join(site_all2, by = c("site_no", "agency_cd", "Latitude", "Longitude"))

# Save the final dataset
write_csv(data_all8, "../_Datasets/Output/data_all.csv")

# Save the median datasets
data_all_median <- data_all7_50th %>%
  left_join(site_all2, by = c("site_no", "agency_cd", "Latitude", "Longitude"))

write_csv(data_all_median, "../_Datasets/Output/data_all_median.csv")
