### This script cleans up and summarizes the data in Bitter Creek

# Clear working space
rm(list = ls())

# Load packages
library(tidyverse)
library(lubridate)
library(dataRetrieval)
library(sp)
library(sf)
library(rgdal)
library(readxl)
library(mapview)
library(nhdplusTools)

### Load the data
dat_all <- read_csv("../_Datasets/Output/data_all_median.csv")

# Find the right parameters for the piper plot
dat_all2 <- dat_all %>%
  filter(Parameter %in% c("Ca", "Cl", "CO3", "HCO3", "K", "Mg", "Na", "SO4")) %>%
  pivot_wider(names_from = "Parameter", values_from = "Value") %>%
  # Remove NA
  filter(if_all(c(Ca, Cl, CO3, HCO3, K, Mg, Na, SO4), .fns = function(x) !is.na(x)))

dat_all3 <- dat_all2 %>%
  mutate(Ca = (Ca * 2)/40.08) %>%
  mutate(Cl = (Cl * 1)/35.45) %>%
  mutate(CO3 = (CO3 * 2)/60.01) %>%
  mutate(HCO3 = (HCO3 * 1/61.02)) %>%
  mutate(K = (K * 1)/39.1) %>%
  mutate(Mg = (Mg * 2)/24.31) %>%
  mutate(Na = (Na * 1)/22.99) %>%
  mutate(SO4 = (SO4 * 2)/96.07) %>%
  ungroup() %>%
  mutate(ID = 1:n())

### Generate the piper plot

source("ggplot_Piper.R")

library(hydrogeo)

dat_all4 <- dat_all3 %>%
  select(Ca, Mg, Na, K, Cl, SO4, CO3, HCO3, ID)

# Convert to percent
dat_all4 <- dat_all3 %>% toPercent()

# Check if the sum is 100
cation.sums <- apply(dat_all4[, c("Ca", "Mg", "Na", "K")], 1, FUN = sum)
anion.sums  <- apply(dat_all4[, c("Cl", "SO4", "CO3", "HCO3")], 1, FUN = sum)

# Transform the data
piper_data <- transform_piper_data(Ca   = dat_all4$Ca,
                                   Mg   = dat_all4$Mg,
                                   Cl   = dat_all4$Cl,
                                   SO4  = dat_all4$SO4,
                                   name = dat_all4$ID)

# Merge with previous data
piper_data2 <- piper_data %>%
  left_join(dat_all3 %>% select(ID, agency_cd), by = c("observation" = "ID"))

fig.plot <- ggplot_piper() +
  geom_point(data = piper_data2, mapping = aes(x, y, color = agency_cd), size = 0.5, stroke = 1) +
  scale_color_brewer(type = "qual", palette = "Set1") +
  theme(legend.position = c(0.1, 0.9), 
        legend.title = element_text(face = "bold", size = 12),
        legend.text = element_text(size = 12))
fig.plot

ggsave("../_Tables_Figures/Figures/Piper_Plot.png", fig.plot)

