### This script cleans up and summarizes the data in Bitter Creek

# Clear working space
rm(list = ls())

# Load packages
library(tidyverse)
library(lubridate)
library(dataRetrieval)
library(sp)
library(sf)
library(rgdal)
library(readxl)
library(mapview)
library(nhdplusTools)
library(scales)
library(ggpubr)
library(tmap)
library(broom)
library(ggpubr)

# Load the data
dat_all <- read_csv("../_Datasets/Output/data_all.csv")

# Load the predicted median data
modeled <- read_excel("../_Datasets/Conductivity_Site_List_20210315.xlsx")

# Load the regression model
fit1 <- readRDS("../_Datasets/Output/LM_90th.rds")

# Predict the 90th percentile
modeled2 <- modeled %>%
  mutate(Pred = predict(fit1, .)) %>%
  rename(Value_90th = Pred)

# Load the river mile data
rv <- read_excel("../_Datasets/BC_Sites_with_RM.xlsx")

# Replace NA in Stream
rv2 <- rv %>%
  replace_na(list(Stream = "Other"))

# Create an exploratory map
rv_site <- rv2 %>%
  st_as_sf(coords = c("Longitude", "Latitude"), crs = 4326)

tm_shape(rv_site) +
  tm_dots(col = "Stream", size = 0.5)

# Remove the "Other" points
rv3 <- rv2 %>%
  filter(!Stream %in% "Other")

### Join the SC data
dat_SC <- dat_all %>%
  filter(Parameter %in% "SC") %>%
  # Remove records with SC < 10
  filter(Value >= 10) %>%
  drop_na(Value)

rv_SC <- rv3 %>%
  left_join(dat_SC, by = c("site_no", "agency_cd"))

# Generate the scatter plot
rv_BC <- rv_SC %>% 
  filter(Stream %in% "Bitter Creek") %>%
  mutate(Dis = as.factor(`Distance to Mouth`)) %>%
  drop_na(Value)

# Fins the miles where Salt Wells, Killpecker, and Little Bitter Creek 
# Flow into Bitter Creek

input <- rv %>%
  select(`Bitter Creek River Mile`, Stream) %>%
  distinct() %>%
  filter(Stream %in% c("Salt Wells Creek", "Killpecker Creek", "Little Bitter Creek")) %>%
  mutate(y = 5) %>%
  mutate(Text = recode(Stream, "Salt Wells Creek" = "SWC",
                       "Killpecker Creek" = "KC",
                       "Little Bitter Creek" = "LBC"))

# Filter the sites in rv_BC for modeled2
modeled_BC <- modeled2 %>%
  semi_join(rv_BC, by = c("site_no", "agency_cd", "COMID")) %>%
  left_join(rv_BC %>% 
              select(site_no, agency_cd, COMID, `Distance to Mouth`) %>%
              distinct(),
            by = c("site_no", "agency_cd")) %>%
  rename("90th" = Value_90th) %>%
  pivot_longer(c("Median", "90th"), names_to = "Predicted SC")
  

BC_p <- ggplot(rv_BC, aes(x = `Distance to Mouth`, y = Value)) +
  geom_point() +
  geom_line(data = modeled_BC,
            aes(x = `Distance to Mouth`, y = value, 
                color = `Predicted SC`), size = 0.5, linetype = "dashed",
            alpha = 0.7) +
  scale_color_manual(values = c("Median" = "#1a9850", "90th" = "#d73027")) +
  scale_fill_manual(values = c("Median" = "#1a9850", "90th" = "#d73027")) +
  geom_vline(data = input, aes(xintercept = `Bitter Creek River Mile`),
             color = "blue") +
  geom_label(data = input, aes(x = `Bitter Creek River Mile`, y = y,
                               label = Text)) +
  theme_bw() +
  scale_x_continuous(name = "Distance to Mouth (mile)") +
  scale_y_continuous(name = "Specific Conductance (μS/cm)",
                     labels = comma, trans = "log10") +
  theme(panel.grid = element_blank(),
        legend.position = "bottom")

ggsave("../_Tables_Figures/Figures/BC_SC_log10_point_pred.png", BC_p, dpi = 300)

### Create a scatter plot for Salt Wells Creek and Killpecker Creek

rv_SWC <- rv_SC %>% 
  filter(Stream %in% "Salt Wells Creek") %>%
  mutate(Dis = as.factor(`Distance to Mouth`)) %>%
  drop_na(Value) %>%
  mutate(`Distance to Mouth` = `Distance to Mouth` - `Bitter Creek River Mile`)

modeled_SWC <- modeled2 %>%
  semi_join(rv_SWC, by = c("site_no", "agency_cd", "COMID")) %>%
  left_join(rv_SWC %>% 
              select(site_no, agency_cd, COMID, `Distance to Mouth`) %>%
              distinct(),
            by = c("site_no", "agency_cd")) %>%
  rename("90th" = Value_90th) %>%
  pivot_longer(c("Median", "90th"), names_to = "Predicted SC")

SWC_p <- ggplot(rv_SWC, aes(x = `Distance to Mouth`, y = Value)) +
  geom_point() +
  geom_line(data = modeled_SWC,
            aes(x = `Distance to Mouth`, y = value, 
                color = `Predicted SC`), size = 0.5, linetype = "dashed",
            alpha = 0.7) +
  scale_color_manual(values = c("Median" = "#1a9850", "90th" = "#d73027")) +
  theme_bw() +
  scale_x_continuous(name = "Distance to Main Stem (mile)") +
  scale_y_continuous(name = "Specific Conductance (μS/cm)",
                     labels = comma, trans = "log10") +
  theme(panel.grid = element_blank(),
        legend.position = "bottom")

rv_KC <- rv_SC %>% 
  filter(Stream %in% "Killpecker Creek") %>%
  mutate(Dis = as.factor(`Distance to Mouth`)) %>%
  drop_na(Value) %>%
  mutate(`Distance to Mouth` = `Distance to Mouth` - `Bitter Creek River Mile`)

modeled_KC <- modeled2 %>%
  semi_join(rv_KC, by = c("site_no", "agency_cd", "COMID")) %>%
  left_join(rv_KC %>% 
              select(site_no, agency_cd, COMID, `Distance to Mouth`) %>%
              distinct(),
            by = c("site_no", "agency_cd")) %>%
  rename("90th" = Value_90th) %>%
  pivot_longer(c("Median", "90th"), names_to = "Predicted SC")

KC_p <- ggplot(rv_KC, aes(x = `Distance to Mouth`, y = Value)) +
  geom_point() +
  geom_line(data = modeled_KC,
            aes(x = `Distance to Mouth`, y = value, 
                color = `Predicted SC`), size = 0.5, linetype = "dashed", 
            alpha = 0.7) +
  scale_color_manual(values = c("Median" = "#1a9850", "90th" = "#d73027")) +
  theme_bw() +
  scale_x_continuous(name = "Distance to Main Stem (mile)") +
  scale_y_continuous(name = "Specific Conductance (μS/cm)",
                     labels = comma, trans = "log10") +
  theme(panel.grid = element_blank()) +
  theme(panel.grid = element_blank(),
        legend.position = "bottom")

ggsave("../_Tables_Figures/Figures/SWC_SC_log10_point_pred.png", SWC_p, dpi = 300)
ggsave("../_Tables_Figures/Figures/KC_SC_log10_point_pred.png", KC_p, dpi = 300)


