### This script creates the big table in the Bitter Creek report

# Clear working space
rm(list = ls())

# Load packages
library(tidyverse)
library(lubridate)
library(dataRetrieval)
library(sp)
library(sf)
library(rgdal)
library(readxl)
library(mapview)
library(nhdplusTools)
library(scales)
library(ggpubr)
library(tmap)
library(broom)
library(ggpubr)
library(e1071)

# Load the data
dat_raw <- read_csv("../_Datasets/Output/data_raw.csv")

dat_all <- read_csv("../_Datasets/Output/data_all.csv")

dat_median <- read_csv("../_Datasets/Output/data_all_median.csv")

# Prepare the combined datasets for dat_raw
dat_raw_c <- dat_raw %>%
  mutate(agency_cd = "Combined")

dat_raw2 <- dat_raw %>% 
  bind_rows(dat_raw_c) %>%
  filter(Parameter %in% "SC")

# Prepare the combined datasets for dat_median
dat_median_c <- dat_median %>% 
  mutate(agency_cd = "Combined")

dat_median2 <- dat_median %>% 
  bind_rows(dat_median_c) %>%
  filter(Parameter %in% "SC")

# Prepare the combined datasets for dat_all
dat_all_c <- dat_all %>% 
  mutate(agency_cd = "Combined")

dat_all2 <- dat_all %>% 
  bind_rows(dat_all_c) %>%
  filter(Parameter %in% "SC")

### Create summary tables

dat_median_summary <- dat_median2 %>%
  group_by(agency_cd) %>%
  # Station number
  summarize(N_station = n_distinct(site_no, Latitude, Longitude),
            # Range
            Range_median = paste0(as.character(min(Value)), "-", 
                                  as.character(max(Value))),
            # % Sample > 1500
            Percent_1500 = sum(Value > 1500)/n() * 100,
            # Skewness
            Skewness = e1071::skewness(log10(Value)),
            # Kurtosis
            Kurtosis = e1071::kurtosis(log10(Value)))

# Range for multiple samples
dat_all_median <- dat_all2 %>%
  group_by(agency_cd) %>%
  summarize(Range_all = paste0(as.character(min(Value)), "-", 
                                  as.character(max(Value))))

# Within year range (% of stations with variability >1500 µS/cm)
dat_var <- dat_all2 %>% 
  mutate(Year = year(sample_dt)) %>%
  group_by(site_no, Year, agency_cd, Latitude, Longitude) %>%
  summarize(Max = max(Value), Min = min(Value)) %>%
  mutate(Diff = (Max - Min)) %>%
  ungroup() %>%
  group_by(site_no, agency_cd, Latitude, Longitude) %>%
  filter(Diff == max(Diff)) %>%
  summarize(Max_Diff = max(Diff)) %>%
  ungroup() %>%
  group_by(agency_cd) %>%
  summarize(Var_Percentage = sum(Max_Diff > 1500)/n() * 100)

dat_all_count <- dat_all2 %>%
  count(site_no, agency_cd, Latitude, Longitude)

# Number of one sample sites
dat_all_count_one <- dat_all_count %>%
  filter(n == 1) %>%
  count(agency_cd) %>%
  rename(One_Sample = n)

# Number of >2 sampel sites
dat_all_count_two <- dat_all_count %>%
  group_by(agency_cd) %>%
  summarize(Two_Sample_Percentage = sum(n > 2)/n() * 100)

# Number of >100 sample sites
dat_all_count_100 <- dat_all_count %>%
  filter(n > 100) %>%
  count(agency_cd) %>%
  rename(OneHundred_Sample = n)

# Percentage of station before 1985
dat_station_1985 <- dat_all2 %>%
  group_by(site_no, agency_cd, Latitude, Longitude) %>%
  mutate(Year = year(sample_dt)) %>%
  summarize(Year = max(Year)) %>%
  group_by(agency_cd) %>%
  summarize(Percentage_1985 = sum(Year < 1985)/n() * 100)

# Sample year
dat_station_year <- dat_all2 %>%
  group_by(site_no, agency_cd, Latitude, Longitude) %>%
  mutate(Year = year(sample_dt)) %>%
  summarize(
    Begin_Year = min(Year),
    End_Year = max(Year)) %>%
  mutate(
    Range_Year = End_Year - Begin_Year + 1
  ) %>%
  group_by(agency_cd) %>%
  summarize(
    Range_Character = str_c(min(Begin_Year), max(End_Year), sep = "-"),
    Span_Year = max(End_Year) - min(Begin_Year) + 1,
    Range_Year = max(Range_Year))

# A version for all agency, not individual stations
dat_station_year_all <- dat_all2 %>%
  mutate(Year = year(sample_dt)) %>%
  group_by(agency_cd) %>%
  summarize(
    Range_Character_all = str_c(min(Year), max(Year), sep = "-"))

# Percentage of station in tributary
bc <- read_excel("../_Datasets/BitterCreek_PredictedConductivityData.xls")

dat_median_tri <- dat_median2 %>%
  left_join(bc %>% select(COMID, StreamName), by = "COMID") %>%
  mutate(Tributary = ifelse(StreamName %in% c("Bitter Creek", 
                                              "Little Bitter Creek",
                                              "Salt Wells Creek",
                                              "Killpecker Creek"), "No", "Yes")) %>%
  group_by(agency_cd) %>%
  summarize(Tributary_Percentage = sum(Tributary == "Yes")/n() * 100)

# Repeated values
dat_repeated <- dat_raw2 %>%
  add_count(site_no, agency_cd, sample_dt, sample_tm, Value, Latitude, Longitude) %>%
  distinct(site_no, agency_cd, sample_dt, sample_tm, Value, Latitude, Longitude, n) %>%
  group_by(agency_cd) %>%
  summarize(Repeated_Percentage = sum(n > 1)/n() * 100)

# % Negative values 
dat_negative <- dat_raw2 %>%
  group_by(agency_cd) %>%
  summarize(Negative_Percentage = sum(Value < 0)/n() * 100)

dat_zero <- dat_raw2 %>%
  group_by(agency_cd) %>%
  summarize(Zero_Percentage = sum(Value == 0)/n() * 100)

dat_small_10 <- dat_raw2 %>%
  group_by(agency_cd) %>%
  summarize(Ten_Percentage = sum(Value < 10)/n() * 100)

dat_large_10000 <- dat_raw2 %>%
  group_by(agency_cd) %>%
  summarize(TenThousand_Percentage = sum(Value > 10000)/n() * 100)

dat_outliers <- dat_raw2 %>%
  group_by(agency_cd) %>%
  mutate(Outliers = ifelse(Value > mean(Value) + 5 * sd(Value), "Yes", "No")) %>%
  summarize(Outliers = sum(Outliers == "Yes")/n() * 100)


### Combine all data
dat_summary <- dat_median_summary %>%
  left_join(dat_all_median, by = "agency_cd") %>%
  left_join(dat_var, by = "agency_cd") %>%
  left_join(dat_all_count_one, by = "agency_cd") %>%
  left_join(dat_all_count_two, by = "agency_cd") %>%
  left_join(dat_all_count_100, by = "agency_cd") %>%
  left_join(dat_station_1985, by = "agency_cd") %>%
  left_join(dat_station_year, by = "agency_cd") %>%
  left_join(dat_station_year_all, by = "agency_cd") %>%
  left_join(dat_repeated, by = "agency_cd") %>%
  left_join(dat_negative, by = "agency_cd") %>%
  left_join(dat_zero, by = "agency_cd") %>%
  left_join(dat_small_10, by = "agency_cd") %>%
  left_join(dat_large_10000, by = "agency_cd") %>%
  left_join(dat_outliers, by = "agency_cd") %>%
  left_join(dat_median_tri, by = "agency_cd") %>%
  mutate(across(.fns = as.character))

dat_summary[is.na(dat_summary)] <- "0"

dat_summary2 <- dat_summary %>%
  mutate(across(-agency_cd, .fns = as.character)) %>%
  pivot_longer(cols = -agency_cd, names_to = "Parameter") %>%
  spread(agency_cd, value) %>%
  select(Parameter, AML, LQD, WQD, SWCCD, USGS, Combined)

  
write_csv(dat_summary2, "../_Tables_Figures/Tables/Table_A2.csv")  




